{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function(ext) { var root = inputs.input_file.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.input_file.basename+ext:root+ext; };"
                    ]
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": "${\n  return  [\n            {\n              \"entry\": inputs.annotation_filename,\n              \"entryname\": inputs.annotation_filename.basename,\n              \"writable\": true\n            }\n          ]\n}\n"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/atdp:v0.0.1"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "File"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--a=",
                        "separate": false
                    },
                    "doc": "Annotation file, tsv\n",
                    "id": "#atdp.cwl/annotation_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "--avd_heat_window=",
                        "separate": false
                    },
                    "doc": "Average tag density window for heatmap\n",
                    "id": "#atdp.cwl/avd_heat_window_bp"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--avd_smooth=",
                        "separate": false
                    },
                    "doc": "Average smooth window (odd), int [0]\n",
                    "id": "#atdp.cwl/avd_smooth_bp"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--avd_window=",
                        "separate": false
                    },
                    "doc": "Average tag density window, int [5000]\n",
                    "id": "#atdp.cwl/avd_window_bp"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--sam_twicechr=",
                        "separate": false
                    },
                    "doc": "The chromosomes to be doubled, string\n",
                    "id": "#atdp.cwl/double_chr"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--f=",
                        "separate": false
                    },
                    "doc": "Fragmentsize, int [150]\n",
                    "id": "#atdp.cwl/fragmentsize_bp"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "--sam_ignorechr=",
                        "separate": false
                    },
                    "doc": "The chromosomes to be ignored, string\n",
                    "id": "#atdp.cwl/ignore_chr"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "--index=",
                        "separate": false
                    },
                    "doc": "Index file\n",
                    "id": "#atdp.cwl/index_file"
                },
                {
                    "type": [
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--in=",
                        "separate": false
                    },
                    "doc": "Input indexed BAM file (optionally +BAI index file in secondaryFiles)\n",
                    "id": "#atdp.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--log=",
                        "separate": false,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename('_atdp.log');\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Log filename\n",
                    "id": "#atdp.cwl/log_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "--m=",
                        "separate": false
                    },
                    "doc": "Mapped reads number\n",
                    "id": "#atdp.cwl/mapped_reads"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--out=",
                        "separate": false,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename('_atdp.tsv');\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Base output file name, tsv\n",
                    "id": "#atdp.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\nset -- \"$0\" \"$@\"\necho \"Original arguments:\"\nfor i in \"$@\";\n    do echo $i;\ndone;\nset -- \"$1\" --a=$(basename \"${2:4}\") \"${@:3}\"\necho Updated arguments:\nfor i in \"$@\";\n    do echo $i;\ndone;\nrefgene-sort -i \"${2:4}\" -o \"${2:4}\" -s \"ORDER BY chrom, strand, CASE strand WHEN '+' THEN txStart WHEN '-' THEN txEnd END\"\natdp \"$@\"\n",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Bash function to run refgene-sort and atdp\n",
                    "id": "#atdp.cwl/script"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool calculates average tag density profile around all annotated TSS.\n\n`default_output_filename` function returns output filename with sufix set as `ext` argument. Function is called when\neither `output_filename` or `log_filename` inputs are not provided.\n\nBefore running `baseCommand`, annotaion file `annotation_filename` is staged into output directory\n(Docker's `--workdir`) with `\"writable\": true` (to allow to overwrite it by `refgene-sort`).\n\nTo run `atdp` index file should be provided (either in `secondaryFiles` of `input_file` or as separate input\n`index_file`)\n\n`baseCommand` runs bash script from `script` input. Script runs `refgene-sort` to sort annotaion file and then runs\n`atdp`. `refgene-sort` - utility to sort refgene annotation files, using MySQL syntax.\n\nOptionally (with cwltool==1.0.20171107133715), script can be simplified to\n    #!/bin/bash\n    set -- \"$0\" \"$@\"\n    refgene-sort -i \"${2:4}\" -o \"${2:4}\" -s \"ORDER BY chrom, strand, CASE strand WHEN '+' THEN txStart WHEN '-' THEN txEnd END\"\n    atdp \"$@\"\nbecause `set -- \"$1\" --a=$(basename \"${2:4}\") \"${@:3}\"` is not needed anymore.\n",
            "id": "#atdp.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#atdp-metadata.yaml",
                "http://schema.org/name": "atdp",
                "http://schema.org/about": "Based on BioWardrobe atdp (https://github.com/cincinnati-childrens-hospital/biowardrobe/tree/master/src/atdp) The software is used to calculate average tag density profile around all annotated TSS. Such data can be used to estimate the success of ChIP-Seq type experiments for some histone modifications (e.g. H3K4me)\n",
                "http://schema.org/url": "https://github.com/Barski-lab/atdp/blob/master/README.md",
                "http://schema.org/codeRepository": "https://github.com/Barski-lab/atdp",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/MIT"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "0.0.1",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/discussionUrl": [
                    "https://github.com/Barski-lab/atdp/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Barski Research Lab",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Andrey Kartashov",
                                "http://schema.org/description": "Main author"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Michael Kotliar",
                                "http://schema.org/description": "Update to work with files instead of DB"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "atdp",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/atdp.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage:\natdp [options] --in=pathToFile --a=pathtoFile --out=pathToFile\n  --a                        \tTab-separated annotation file\n  --avd_bsmooth              \tAverage smooth window for gene body\n  --avd_guid                 \tGenelist uid\n  --avd_heat_window          \tAverage tag density window for heatmap\n  --avd_smooth               \tAverage smooth window (odd)\n  --avd_window               \tAverage tag density window\n  --f                        \tFragmentsize, bp\n  --in                       \tInput BAM file\n  --index                    \tInput index bai file\n  --log                      \tLog file name (default is ./logfile_def.log)\n  --out                      \tBase output filename\n  --sam_ignorechr            \tWhich chromosome to ignore\n  --sam_twicechr             \tWhich chromosome to double\n  --m                         Mapped reads number\n",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.log_filename == \"\"){\n    return default_output_filename('_atdp.log');\n  } else {\n    return inputs.log_filename;\n  }\n}\n"
                    },
                    "id": "#atdp.cwl/log_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_filename == \"\"){\n    return default_output_filename('_atdp.tsv');\n  } else {\n    return inputs.output_filename;\n  }\n}\n"
                    },
                    "id": "#atdp.cwl/result_file"
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "Input BAM file",
                    "doc": "Input BAM file, sorted by coordinates",
                    "id": "#bam-bedgraph-bigwig.cwl/bam_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Output filename for generated bedGraph",
                    "id": "#bam-bedgraph-bigwig.cwl/bedgraph_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Output filename for generated bigWig",
                    "id": "#bam-bedgraph-bigwig.cwl/bigwig_filename"
                },
                {
                    "type": "File",
                    "doc": "Tab delimited chromosome length file: <chromName><TAB><chromSize>",
                    "id": "#bam-bedgraph-bigwig.cwl/chrom_length_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Change strand af the mate read, so both reads come from the same strand",
                    "id": "#bam-bedgraph-bigwig.cwl/dutp"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Set fixed fragment size for genome coverage calculation",
                    "id": "#bam-bedgraph-bigwig.cwl/fragment_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Parameter to calculate scale as 1000000/mapped_reads_number. Ignored by bedtools-genomecov.cwl in\nbam_to_bedgraph step if scale is provided\n",
                    "id": "#bam-bedgraph-bigwig.cwl/mapped_reads_number"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Enable paired-end genome coverage calculation",
                    "id": "#bam-bedgraph-bigwig.cwl/pairchip"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "Coefficient to scale the genome coverage by a constant factor",
                    "id": "#bam-bedgraph-bigwig.cwl/scale"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Calculate genome coverage for each part of the splitted by 'N' and 'D' read",
                    "id": "#bam-bedgraph-bigwig.cwl/split"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Calculate genome coverage of intervals from a specific strand",
                    "id": "#bam-bedgraph-bigwig.cwl/strand"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#bam-bedgraph-bigwig.cwl/sort_bedgraph/sorted_file",
                    "label": "bedGraph output file",
                    "doc": "Output bedGraph file",
                    "id": "#bam-bedgraph-bigwig.cwl/bedgraph_file"
                },
                {
                    "type": "File",
                    "outputSource": "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig/bigwig_file",
                    "doc": "Output bigWig file",
                    "id": "#bam-bedgraph-bigwig.cwl/bigwig_file"
                }
            ],
            "steps": [
                {
                    "run": "#bedtools-genomecov.cwl",
                    "in": [
                        {
                            "default": "-bg",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/depth"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/dutp",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/du"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/fragment_size",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/fragment_size"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/bam_file",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/input_file"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/mapped_reads_number",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/mapped_reads_number"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/bedgraph_filename",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/output_filename"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/pairchip",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/pairchip"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/scale",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/scale"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/split",
                            "valueFrom": "${\n  if (self == null){\n    return true;\n  } else {\n    return self;\n  }\n}\n",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/split"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/strand",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/strand"
                        }
                    ],
                    "out": [
                        "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/genome_coverage_file"
                    ],
                    "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph"
                },
                {
                    "run": "#linux-sort.cwl",
                    "in": [
                        {
                            "default": [
                                "1,1",
                                "2,2n"
                            ],
                            "id": "#bam-bedgraph-bigwig.cwl/sort_bedgraph/key"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/genome_coverage_file",
                            "id": "#bam-bedgraph-bigwig.cwl/sort_bedgraph/unsorted_file"
                        }
                    ],
                    "out": [
                        "#bam-bedgraph-bigwig.cwl/sort_bedgraph/sorted_file"
                    ],
                    "id": "#bam-bedgraph-bigwig.cwl/sort_bedgraph"
                },
                {
                    "run": "#ucsc-bedgraphtobigwig.cwl",
                    "in": [
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/sort_bedgraph/sorted_file",
                            "id": "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig/bedgraph_file"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/chrom_length_file",
                            "id": "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig/chrom_length_file"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/bigwig_filename",
                            "id": "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig/output_filename"
                        }
                    ],
                    "out": [
                        "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig/bigwig_file"
                    ],
                    "id": "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig"
                }
            ],
            "doc": "Workflow converts input BAM file into bigWig and bedGraph files.\n\nInput BAM file should be sorted by coordinates (required by `bam_to_bedgraph` step).\n\nIf `split` input is not provided use true by default. Default logic is implemented in `valueFrom` field of `split`\ninput inside `bam_to_bedgraph` step to avoid possible bug in cwltool with setting default values for workflow inputs.\n\n`scale` has higher priority over the `mapped_reads_number`. The last one is used to calculate `-scale` parameter for\n`bedtools genomecov` (step `bam_to_bedgraph`) only in a case when input `scale` is not provided. All logic is\nimplemented inside `bedtools-genomecov.cwl`.\n\n`bigwig_filename` defines the output name only for generated bigWig file. `bedgraph_filename` defines the output name\nfor generated bedGraph file and can influence on generated bigWig filename in case when `bigwig_filename` is not provided.\n\nAll workflow inputs and outputs don't have `format` field to avoid format incompatibility errors when workflow is used\nas subworkflow.",
            "id": "#bam-bedgraph-bigwig.cwl",
            "http://schema.org/name": "bam-bedgraph-bigwig",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { var ext = (inputs.depth == \"-bg\" || inputs.depth == \"-bga\")?\".bedGraph\":\".tab\"; return inputs.input_file.location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.') + ext; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/bedtools2:v2.26.0"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 17,
                        "prefix": "-g"
                    },
                    "doc": "Input genome file. Needed only when -i flag. The genome file is tab delimited <chromName><TAB><chromSize>\n",
                    "id": "#bedtools-genomecov.cwl/chrom_length_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#bedtools-genomecov.cwl/depth/depth",
                            "symbols": [
                                "#bedtools-genomecov.cwl/depth/depth/-bg",
                                "#bedtools-genomecov.cwl/depth/depth/-bga",
                                "#bedtools-genomecov.cwl/depth/depth/-d",
                                "#bedtools-genomecov.cwl/depth/depth/-dz"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Report the depth type. By default, bedtools genomecov will compute a histogram of coverage\nfor the genome file provided (intputs.chrom_length_file)\n",
                    "id": "#bedtools-genomecov.cwl/depth"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "-du"
                    },
                    "doc": "Change strand af the mate read (so both reads from the same strand) useful for strand specific.\nWorks for BAM files only\n",
                    "id": "#bedtools-genomecov.cwl/du"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "-fs"
                    },
                    "doc": "Set fixed fragment size\n",
                    "id": "#bedtools-genomecov.cwl/fragment_size"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 16,
                        "valueFrom": "${\n  var prefix = ((/.*\\.bam$/i).test(inputs.input_file.path))?'-ibam':'-i';\n  return [prefix, inputs.input_file.path];\n}\n"
                    },
                    "doc": "The input file can be in BAM format (Note: BAM must be sorted by position) or <bed/gff/vcf>.\nPrefix is selected on the base of input file extension\n",
                    "id": "#bedtools-genomecov.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "prefix": "-3"
                    },
                    "doc": "Calculate coverage of 3\" positions (instead of entire interval)\n",
                    "id": "#bedtools-genomecov.cwl/m3"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "-5"
                    },
                    "doc": "Calculate coverage of 5\" positions (instead of entire interval)\n",
                    "id": "#bedtools-genomecov.cwl/m5"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-scale",
                        "valueFrom": "${\n  if (inputs.scale){\n    return null;\n  } else if (inputs.mapped_reads_number) {\n    return 1000000/inputs.mapped_reads_number;\n  } else {\n    return null;\n  }\n}\n"
                    },
                    "doc": "Optional parameter to calculate scale as 1000000/mapped_reads_number if inputs.scale is not provided\n",
                    "id": "#bedtools-genomecov.cwl/mapped_reads_number"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "-max"
                    },
                    "doc": "Combine all positions with a depth >= max into\na single bin in the histogram. Irrelevant\nfor -d and -bedGraph\n- (INTEGER)\n",
                    "id": "#bedtools-genomecov.cwl/max"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Name for generated output file\n",
                    "id": "#bedtools-genomecov.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "-pc"
                    },
                    "doc": "pair-end chip seq experiment\n",
                    "id": "#bedtools-genomecov.cwl/pairchip"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-scale"
                    },
                    "doc": "Scale the coverage by a constant factor.\nEach coverage value is multiplied by this factor before being reported.\nUseful for normalizing coverage by, e.g., reads per million (RPM).\n- Default is 1.0; i.e., unscaled.\n- (FLOAT)\n",
                    "id": "#bedtools-genomecov.cwl/scale"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "-split"
                    },
                    "doc": "treat \"split\" BAM or BED12 entries as distinct BED intervals.\nwhen computing coverage.\nFor BAM files, this uses the CIGAR \"N\" and \"D\" operations\nto infer the blocks for computing coverage.\nFor BED12 files, this uses the BlockCount, BlockStarts, and BlockEnds\nfields (i.e., columns 10,11,12).\n",
                    "id": "#bedtools-genomecov.cwl/split"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "-strand"
                    },
                    "doc": "Calculate coverage of intervals from a specific strand.\nWith BED files, requires at least 6 columns (strand is column 6).\n- (STRING): can be + or -\n",
                    "id": "#bedtools-genomecov.cwl/strand"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "doc": "Generated genome coverage output file\n",
                    "id": "#bedtools-genomecov.cwl/genome_coverage_file",
                    "outputBinding": {
                        "glob": "${\n    return inputs.output_filename ? inputs.output_filename : default_output_filename();\n}\n"
                    }
                }
            ],
            "stdout": "${\n    return inputs.output_filename ? inputs.output_filename : default_output_filename();\n}\n",
            "baseCommand": [
                "bedtools",
                "genomecov"
            ],
            "doc": "Tool calculates genome coverage from input bam/bed/gff/vcf using `bedtools genomecov`\n\nDepending on `input_file` extension additional prefix is used: if `*.bam` use `-ibam`, else use `-i`.\n\n`scale` and `mapped_reads_number` inputs result in the same parameter `-scale`. If `scale` is not provided, check if\n`mapped_reads_number` is not null and calculate `-scale` as `1000000/mapped_reads_number`. If both inputs are\nnull, `bedtools genomecov` will use its default scaling value.\n\n`default_output_filename` function returns default output filename and is used when `output_filename` is not provided.\nDefault output file extention is `.tab`. If bedGraph should be generated (check flags `inputs.depth`), extension is\nupdated to `.bedGraph`. Default basename of the output file is generated on the base of `input_file` basename.\n",
            "id": "#bedtools-genomecov.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#bedtools-metadata.yaml",
                "http://schema.org/name": "bedtools",
                "http://schema.org/about": "A software suite for the comparison, manipulation and annotation of genomic features in browser extensible data (BED) and general feature format (GFF) format. BEDTools also supports the comparison of sequence alignments in BAM format to both BED and GFF features. The tools are extremely efficient and allow the user to compare large datasets (e.g. next-generation sequencing data) with both public and custom genome annotation tracks. BEDTools can be combined with one another as well as with standard UNIX commands, thus facilitating routine genomics tasks as well as pipelines that can quickly answer intricate questions of large genomic datasets.\n",
                "http://schema.org/url": "http://bedtools.readthedocs.org",
                "http://schema.org/codeRepository": "https://github.com/arq5x/bedtools2",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-2.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "2.26.0",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/publication": [
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#bedtools-metadata.yaml/10.1093/bioinformatics/btq033",
                        "datePublished": "28 January 2010",
                        "http://schema.org/name": "BEDTools: a flexible suite of utilities for comparing genomic features",
                        "http://schema.org/author": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Aaron R. Quinlan"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Ira M. Hall"
                            }
                        ],
                        "http://schema.org/url": "https://academic.oup.com/bioinformatics/article-lookup/doi/10.1093/bioinformatics/btq033"
                    }
                ],
                "http://schema.org/discussionUrl": [
                    "https://github.com/arq5x/bedtools2/issues",
                    "https://groups.google.com/forum/#!forum/bedtools-discuss"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "University of Utah",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Aaron Quinlan",
                                "http://schema.org/description": "Main author"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Neil Kindlon",
                                "http://schema.org/description": "Main author"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "bedtools-genomecov",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/bedtools-genomecov.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage: bedtools genomecov [OPTIONS] -i <bed/gff/vcf> -g <genome>\n\nOptions:\n\t-ibam\t\tThe input file is in BAM format.\n\t\t\tNote: BAM _must_ be sorted by position\n\n\t-d\t\tReport the depth at each genome position (with one-based coordinates).\n\t\t\tDefault behavior is to report a histogram.\n\n\t-dz\t\tReport the depth at each genome position (with zero-based coordinates).\n\t\t\tReports only non-zero positions.\n\t\t\tDefault behavior is to report a histogram.\n\n\t-bg\t\tReport depth in BedGraph format. For details, see:\n\t\t\tgenome.ucsc.edu/goldenPath/help/bedgraph.html\n\n\t-bga\t\tReport depth in BedGraph format, as above (-bg).\n\t\t\tHowever with this option, regions with zero\n\t\t\tcoverage are also reported. This allows one to\n\t\t\tquickly extract all regions of a genome with 0\n\t\t\tcoverage by applying: \"grep -w 0$\" to the output.\n\n\t-split\t\tTreat \"split\" BAM or BED12 entries as distinct BED intervals.\n\t\t\twhen computing coverage.\n\t\t\tFor BAM files, this uses the CIGAR \"N\" and \"D\" operations\n\t\t\tto infer the blocks for computing coverage.\n\t\t\tFor BED12 files, this uses the BlockCount, BlockStarts, and BlockEnds\n\t\t\tfields (i.e., columns 10,11,12).\n\n\t-strand\t\tCalculate coverage of intervals from a specific strand.\n\t\t\tWith BED files, requires at least 6 columns (strand is column 6).\n\t\t\t- (STRING): can be + or -\n\n\t-pc\t\tCalculate coverage of pair-end fragments.\n\t\t\tWorks for BAM files only\n\t-fs\t\tForce to use provided fragment size instead of read length\n\t\t\tWorks for BAM files only\n\t-du\t\tChange strand af the mate read (so both reads from the same strand) useful for strand specific\n\t\t\tWorks for BAM files only\n\t-5\t\tCalculate coverage of 5\" positions (instead of entire interval).\n\n\t-3\t\tCalculate coverage of 3\" positions (instead of entire interval).\n\n\t-max\t\tCombine all positions with a depth >= max into\n\t\t\ta single bin in the histogram. Irrelevant\n\t\t\tfor -d and -bedGraph\n\t\t\t- (INTEGER)\n\n\t-scale\t\tScale the coverage by a constant factor.\n\t\t\tEach coverage value is multiplied by this factor before being reported.\n\t\t\tUseful for normalizing coverage by, e.g., reads per million (RPM).\n\t\t\t- Default is 1.0; i.e., unscaled.\n\t\t\t- (FLOAT)\n\n\t-trackline\tAdds a UCSC/Genome-Browser track line definition in the first line of the output.\n\t\t\t- See here for more details about track line definition:\n\t\t\t      http://genome.ucsc.edu/goldenPath/help/bedgraph.html\n\t\t\t- NOTE: When adding a trackline definition, the output BedGraph can be easily\n\t\t\t      uploaded to the Genome Browser as a custom track,\n\t\t\t      BUT CAN NOT be converted into a BigWig file (w/o removing the first line).\n\n\t-trackopts\tWrites additional track line definition parameters in the first line.\n\t\t\t- Example:\n\t\t\t   -trackopts 'name=\"My Track\" visibility=2 color=255,30,30'\n\t\t\t   Note the use of single-quotes if you have spaces in your parameters.\n\t\t\t- (TEXT)\n\nNotes:\n\t(1) The genome file should tab delimited and structured as follows:\n\t <chromName><TAB><chromSize>\n\n\tFor example, Human (hg19):\n\tchr1\t249250621\n\tchr2\t243199373\n\t...\n\tchr18_gl000207_random\t4262\n\n\t(2) The input BED (-i) file must be grouped by chromosome.\n\t A simple \"sort -k 1,1 <BED> > <BED>.sorted\" will suffice.\n\n\t(3) The input BAM (-ibam) file must be sorted by position.\n\t A \"samtools sort <BAM>\" should suffice.\n\nTips:\n\tOne can use the UCSC Genome Browser's MySQL database to extract\n\tchromosome sizes. For example, H. sapiens:\n\n\tmysql --user=genome --host=genome-mysql.cse.ucsc.edu -A -e \\\n\t\"select chrom, size from hg19.chromInfo\" > hg19.genome\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { if (inputs.output_filename == \"\"){ var root = inputs.bambai_pair.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.bambai_pair.basename+\".bam\":root+\".bam\"; } else { return inputs.output_filename; } };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/deeptools:v0.0.1"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "--ATACshift"
                    },
                    "doc": "Shift commonly done for ATAC-seq. This is equivalent to \u2013shift 4 -5 5 -4",
                    "id": "#deeptools-alignmentsieve.cwl/atac_shift"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--bam"
                    },
                    "doc": "An indexed BAM file",
                    "id": "#deeptools-alignmentsieve.cwl/bambai_pair"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "--blackListFileName"
                    },
                    "doc": "A BED or GTF file containing regions that should be excluded from all analyses",
                    "id": "#deeptools-alignmentsieve.cwl/blacklisted_regions"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "--ignoreDuplicates"
                    },
                    "doc": "If set, reads that have the same orientation and start position will be considered only once.\nIf reads are paired, the mate\u2019s position also has to coincide to ignore a read\n",
                    "id": "#deeptools-alignmentsieve.cwl/ignore_duplicates"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--maxFragmentLength"
                    },
                    "doc": "The maximum fragment length needed for read/pair inclusion",
                    "id": "#deeptools-alignmentsieve.cwl/max_fragment_length"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--minFragmentLength"
                    },
                    "doc": "The minimum fragment length needed for read/pair inclusion",
                    "id": "#deeptools-alignmentsieve.cwl/min_fragment_length"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--minMappingQuality"
                    },
                    "doc": "If set, only reads that have a mapping quality score of at least this are considered",
                    "id": "#deeptools-alignmentsieve.cwl/min_mapping_quality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "--outFile",
                        "valueFrom": "$(default_output_filename())"
                    },
                    "default": "",
                    "doc": "The file to write results to. These are the alignments or fragments that pass the filtering criteria",
                    "id": "#deeptools-alignmentsieve.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--shift"
                    },
                    "doc": "Shift the left and right end of a read for BAM files",
                    "id": "#deeptools-alignmentsieve.cwl/shift"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "--numberOfProcessors"
                    },
                    "doc": "Number of processors to use",
                    "id": "#deeptools-alignmentsieve.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.log"
                    },
                    "doc": "alignmentSieve log",
                    "id": "#deeptools-alignmentsieve.cwl/alignmentsieve_log"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.bam"
                    },
                    "doc": "Filtered BAM file",
                    "id": "#deeptools-alignmentsieve.cwl/filtered_bam_file"
                }
            ],
            "baseCommand": [
                "alignmentSieve",
                "--filterMetrics",
                "alignmentsieve.log"
            ],
            "label": "AlignmentSieve - utility from deepTools for BAM/CRAM file filtering",
            "doc": "For BAM files only. Only selected parameters are implemented.\n",
            "id": "#deeptools-alignmentsieve.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#deeptools-metadata.yaml",
                "http://schema.org/name": "deepTools",
                "http://schema.org/about": "deepTools is a suite of python tools particularly developed for the efficient analysis of high-throughput sequencing data, such as ChIP-seq, RNA-seq or MNase-seq.\n"
            },
            "http://schema.org/name": "AlignmentSieve - utility from deepTools for BAM/CRAM file filtering",
            "http://schema.org/alternateName": "AlignmentSieve - tool for filtering alignments in a BAM/CRAM file according the the specified parameters",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/deeptools-alignmentsieve.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "usage: Example usage: alignmentSieve.py -b sample1.bam -o sample1.filtered.bam --minMappingQuality 10 --filterMetrics log.txt\n\nThis tool filters alignments in a BAM/CRAM file according the the specified parameters. It can optionally output to BEDPE format.\n\noptional arguments:\n  -h, --help            show this help message and exit\n\nRequired arguments:\n  --bam FILE1, -b FILE1\n                        An indexed BAM file.\n  --outFile OUTFILE, -o OUTFILE\n                        The file to write results to. These are the alignments\n                        or fragments that pass the filtering criteria.\n\nGeneral arguments:\n  --numberOfProcessors INT, -p INT\n                        Number of processors to use. Type \"max/2\" to use half\n                        the maximum number of processors or \"max\" to use all\n                        available processors.\n  --filterMetrics FILE.log\n                        The number of entries in total and filtered are saved\n                        to this file\n  --filteredOutReads filtered.bam\n                        If desired, all reads NOT passing the filtering\n                        criteria can be written to this file.\n  --label sample1, -l sample1\n                        User defined label instead of the default label (file\n                        name).\n  --smartLabels         Instead of manually specifying a labels for the input\n                        file, this causes deepTools to use the file name after\n                        removing the path and extension.\n  --verbose, -v         Set to see processing messages.\n  --version             show program's version number and exit\n  --shift SHIFT [SHIFT ...]\n                        Shift the left and right end of a read (for BAM files)\n                        or a fragment (for BED files). A positive value shift\n                        an end to the right (on the + strand) and a negative\n                        value shifts a fragment to the left. Either 2 or 4\n                        integers can be provided. For example, \"2 -3\" will\n                        shift the left-most fragment end two bases to the\n                        right and the right-most end 3 bases to the left. If 4\n                        integers are provided, then the first and last two\n                        refer to fragments whose read 1 is on the left or\n                        right, respectively. Consequently, it is possible to\n                        take strand into consideration for strand-specific\n                        protocols. A fragment whose length falls below 1 due\n                        to shifting will not be written to the output. See the\n                        online documentation for graphical examples. Note that\n                        non-properly-paired reads will be filtered.\n  --ATACshift           Shift the produced BAM file or BEDPE regions as\n                        commonly done for ATAC-seq. This is equivalent to\n                        --shift 4 -5 5 -4.\n\nOutput arguments:\n  --BED                 Instead of producing BAM files, write output in BEDPE\n                        format (as defined by MACS2). Note that only\n                        reads/fragments passing filtering criterion are\n                        written in BEDPE format.\n\nOptional arguments:\n  --filterRNAstrand {forward,reverse}\n                        Selects RNA-seq reads (single-end or paired-end) in\n                        the given strand.\n  --ignoreDuplicates    If set, reads that have the same orientation and start\n                        position will be considered only once. If reads are\n                        paired, the mate's position also has to coincide to\n                        ignore a read.\n  --minMappingQuality INT\n                        If set, only reads that have a mapping quality score\n                        of at least this are considered.\n  --samFlagInclude INT  Include reads based on the SAM flag. For example, to\n                        get only reads that are the first mate, use a flag of\n                        64. This is useful to count properly paired reads only\n                        once, as otherwise the second mate will be also\n                        considered for the coverage.\n  --samFlagExclude INT  Exclude reads based on the SAM flag. For example, to\n                        get only reads that map to the forward strand, use\n                        --samFlagExclude 16, where 16 is the SAM flag for\n                        reads that map to the reverse strand.\n  --blackListFileName BED file [BED file ...], -bl BED file [BED file ...]\n                        A BED or GTF file containing regions that should be\n                        excluded from all analyses. Currently this works by\n                        rejecting genomic chunks that happen to overlap an\n                        entry. Consequently, for BAM files, if a read\n                        partially overlaps a blacklisted region or a fragment\n                        spans over it, then the read/fragment might still be\n                        considered. Please note that you should adjust the\n                        effective genome size, if relevant.\n  --minFragmentLength INT\n                        The minimum fragment length needed for read/pair\n                        inclusion. This option is primarily useful in ATACseq\n                        experiments, for filtering mono- or di-nucleosome\n                        fragments.\n  --maxFragmentLength INT\n                        The maximum fragment length needed for read/pair\n                        inclusion.\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function(ext) { var root = inputs.input_filename.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.input_filename.basename+ext:root+ext; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/iaintersect:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--a=",
                        "separate": false
                    },
                    "doc": "Annotation file, tsv",
                    "id": "#iaintersect.cwl/annotation_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--sam_ignorechr=",
                        "separate": false
                    },
                    "doc": "The chromosome to be ignored, string\n",
                    "id": "#iaintersect.cwl/ignore_chr"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--in=",
                        "separate": false
                    },
                    "doc": "Input filename with MACS2 peak calling results, tsv",
                    "id": "#iaintersect.cwl/input_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--log=",
                        "separate": false,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename('_iaintersect.log');\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Log filename\n",
                    "id": "#iaintersect.cwl/log_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--out=",
                        "separate": false,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename('_iaintersect.tsv');\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Base output file name, tsv\n",
                    "id": "#iaintersect.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--promoter=",
                        "separate": false
                    },
                    "doc": "Promoter region around TSS, base pairs\n",
                    "id": "#iaintersect.cwl/promoter_bp"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--upstream=",
                        "separate": false
                    },
                    "doc": "Upstream region before promoter, base pairs\n",
                    "id": "#iaintersect.cwl/upstream_bp"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.log_filename == \"\"){\n    return default_output_filename('_iaintersect.log');\n  } else {\n    return inputs.log_filename;\n  }\n}\n"
                    },
                    "id": "#iaintersect.cwl/log_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_filename == \"\"){\n    return default_output_filename('_iaintersect.tsv');\n  } else {\n    return inputs.output_filename;\n  }\n}\n"
                    },
                    "id": "#iaintersect.cwl/result_file"
                }
            ],
            "baseCommand": [
                "iaintersect"
            ],
            "doc": "Tool assigns each peak obtained from MACS2 to a gene and region (upstream, promoter, exon, intron, intergenic)\n\n`default_output_filename` function returns output filename with sufix set as `ext` argument. Function is called when\neither `output_filename` or `log_filename` inputs are not provided.\n",
            "id": "#iaintersect.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#iaintersect-metadata.yaml",
                "http://schema.org/name": "iaintersect",
                "http://schema.org/about": "Based on BioWardrobe iaintersect (https://github.com/cincinnati-childrens-hospital/biowardrobe/tree/master/src/iaintersect) The software assigns each peak obtained from MACS2 to a gene and region (upstream, promoter, exon, intron, intergenic).\n",
                "http://schema.org/url": "https://github.com/Barski-lab/iaintersect/blob/master/README.md",
                "http://schema.org/codeRepository": "https://github.com/Barski-lab/iaintersect",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/MIT"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "0.0.1",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/discussionUrl": [
                    "https://github.com/Barski-lab/iaintersect/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Barski Research Lab",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Andrey Kartashov",
                                "http://schema.org/description": "Main author"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Michael Kotliar",
                                "http://schema.org/description": "Update to work with files instead of DB"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "iaintersect",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/iaintersect.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage:\n  iaintersect [options] --in=pathToFile --a=pathtoFile --out=pathToFile\n  --a                        \tTab-separated annotation file\n  --in                       \tInput filename with MACS2 peak calling results, xls\n  --log                      \tLog filename (default is ./logfile_def.log)\n  --out                      \tBase output file name\n  --promoter                 \tPromoter region around TSS in bp\n  --sam_ignorechr            \tThe chromosome to be ignored\n  --upstream                 \tUpstream region before promoter in bp\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var get_output_filename = function() { if (inputs.output_filename) { return inputs.output_filename; } return inputs.unsorted_file.location.split('/').slice(-1)[0]; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-k"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "-k, --key=POS1[,POS2]\nstart a key at POS1, end it at POS2 (origin 1)\n",
                    "id": "#linux-sort.cwl/key"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Name for generated output file\n",
                    "id": "#linux-sort.cwl/output_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#linux-sort.cwl/unsorted_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#linux-sort.cwl/sorted_file",
                    "outputBinding": {
                        "glob": "$(get_output_filename())"
                    }
                }
            ],
            "stdout": "$(get_output_filename())",
            "baseCommand": [
                "sort"
            ],
            "doc": "Tool sorts data from `unsorted_file` by key\n\n`default_output_filename` function returns file name identical to `unsorted_file`, if `output_filename` is not provided.\n",
            "id": "#linux-sort.cwl",
            "http://schema.org/name": "linux-sort",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/linux-sort.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_name = function(input_staged, sufix) { input_staged = input_staged || false; sufix = sufix || \"_macs\"; if (inputs.trigger == false && input_staged){ return input_staged.basename; } else { if (Object.prototype.toString.call(inputs.treatment_file) === '[object Array]'){ return inputs.treatment_file[0].location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.')+sufix; } else { return inputs.treatment_file.location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.')+sufix; } } }"
                    ]
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": "${\n  var listing = []\n  if (inputs.peak_xls_file_staged){\n    listing.push(\n      {\n        \"entry\": inputs.peak_xls_file_staged,\n        \"entryname\": inputs.peak_xls_file_staged.basename,\n        \"writable\": true\n      }\n    )\n  }\n  if (inputs.narrow_peak_file_staged){\n    listing.push(\n      {\n        \"entry\": inputs.narrow_peak_file_staged,\n        \"entryname\": inputs.narrow_peak_file_staged.basename,\n        \"writable\": true\n      }\n    )\n  }\n  if (inputs.broad_peak_file_staged){\n    listing.push(\n      {\n        \"entry\": inputs.broad_peak_file_staged,\n        \"entryname\": inputs.broad_peak_file_staged.basename,\n        \"writable\": true\n      }\n    )\n  }\n  if (inputs.gapped_peak_file_staged){\n    listing.push(\n      {\n        \"entry\": inputs.gapped_peak_file_staged,\n        \"entryname\": inputs.gapped_peak_file_staged.basename,\n        \"writable\": true\n      }\n    )\n  }\n  if (inputs.peak_summits_file_staged){\n    listing.push(\n      {\n        \"entry\": inputs.peak_summits_file_staged,\n        \"entryname\": inputs.peak_summits_file_staged.basename,\n        \"writable\": true\n      }\n    )\n  }\n  if (inputs.moder_r_file_staged){\n    listing.push(\n      {\n        \"entry\": inputs.moder_r_file_staged,\n        \"entryname\": inputs.moder_r_file_staged.basename,\n        \"writable\": true\n      }\n    )\n  }\n  if (inputs.treat_pileup_bdg_file_staged){\n    listing.push(\n      {\n        \"entry\": inputs.treat_pileup_bdg_file_staged,\n        \"entryname\": inputs.treat_pileup_bdg_file_staged.basename,\n        \"writable\": true\n      }\n    )\n  }\n  if (inputs.control_lambda_bdg_file_staged){\n    listing.push(\n      {\n        \"entry\": inputs.control_lambda_bdg_file_staged,\n        \"entryname\": inputs.control_lambda_bdg_file_staged.basename,\n        \"writable\": true\n      }\n    )\n  }\n  if (inputs.macs_log_staged){\n    listing.push(\n      {\n        \"entry\": inputs.macs_log_staged,\n        \"entryname\": inputs.macs_log_staged.basename,\n        \"writable\": true\n      }\n    )\n  }\n  return listing;\n}\n"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/macs2:v2.1.1"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 17,
                        "prefix": "--bdg"
                    },
                    "doc": "If this flag is on, MACS will store the fragment pileup, control lambda, -log10pvalue and -log10qvalue scores in bedGraph files.\nThe bedGraph files will be stored in current directory named NAME+\u2019_treat_pileup.bdg\u2019 for treatment data, NAME+\u2019_control_lambda.bdg\u2019\nfor local lambda values from control, NAME+\u2019_treat_pvalue.bdg\u2019 for Poisson pvalue scores (in -log10(pvalue) form),\nand NAME+\u2019_treat_qvalue.bdg\u2019 for q-value scores from\nBenjamini\u2013Hochberg\u2013Yekutieli procedure <http://en.wikipedia.org/wiki/False_discovery_rate#Dependent_tests>\nDEFAULT: False\n",
                    "id": "#macs2-callpeak.cwl/bdg"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 36,
                        "prefix": "--broad"
                    },
                    "doc": "If set, MACS will try to call broad peaks by linking nearby highly enriched\nregions. The linking region is controlled by another cutoff through --linking-cutoff.\nThe maximum linking region length is 4 times of d from MACS.\nDEFAULT: False\n",
                    "id": "#macs2-callpeak.cwl/broad"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 37,
                        "prefix": "--broad-cutoff"
                    },
                    "doc": "Cutoff for broad region. This option is not available\nunless --broad is set. If -p is set, this is a pvalue\ncutoff, otherwise, it's a qvalue cutoff.\nDEFAULT: 0.1\n",
                    "id": "#macs2-callpeak.cwl/broad_cutoff"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "For staging in a case of trigger is set to false",
                    "id": "#macs2-callpeak.cwl/broad_peak_file_staged"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 16,
                        "prefix": "--buffer-size"
                    },
                    "doc": "Buffer size for incrementally increasing internal\narray size to store reads alignment information. In\nmost cases, you don't have to change this parameter.\nHowever, if there are large number of\nchromosomes/contigs/scaffolds in your alignment, it's\nrecommended to specify a smaller buffer size in order\nto decrease memory usage (but it will take longer time\nto read alignment files). Minimum memory requested for\nreading an alignment file is about # of CHROMOSOME *\nBUFFER_SIZE * 2 Bytes.\nDEFAULT: 100000\n",
                    "id": "#macs2-callpeak.cwl/buffer_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 21,
                        "prefix": "--bw"
                    },
                    "doc": "Band width for picking regions to compute  fragment  size.  This\nvalue is only used while building the shifting model\nDEFAULT: 300\n",
                    "id": "#macs2-callpeak.cwl/bw"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 39,
                        "prefix": "--call-summits"
                    },
                    "doc": "If set, MACS will use a more sophisticated signal processing approach to\nfind subpeak summits in each enriched peak region.\nDEFAULT: False\n",
                    "id": "#macs2-callpeak.cwl/call_summits"
                },
                {
                    "type": [
                        "null",
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "-c"
                    },
                    "doc": "The control or mock data file. Please follow the same direction as for -t/\u2013treatment",
                    "id": "#macs2-callpeak.cwl/control_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "For staging in a case of trigger is set to false",
                    "id": "#macs2-callpeak.cwl/control_lambda_bdg_file_staged"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 38,
                        "prefix": "--cutoff-analysis"
                    },
                    "doc": "While set, MACS2 will analyze number or total length of peaks that can be\ncalled by different p-value cutoff then output a summary table to help user\ndecide a better cutoff. The table will be saved in NAME_cutoff_analysis.txt\nfile. Note, minlen and maxgap may affect the results. WARNING: May take ~30\nfolds longer time to finish.\nDEFAULT: False\n",
                    "id": "#macs2-callpeak.cwl/cutoff_analysis"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 31,
                        "prefix": "--down-sample"
                    },
                    "doc": "When set, random sampling method will scale down the bigger sample. By default,\nMACS uses linear scaling. Warning: This option will make your result unstable\nand irreproducible since each time, random reads would be selected. Consider\nto use ''randsample'' script instead. <not implmented>If used together with\n--SPMR, 1 million unique reads will be randomly picked.</not implemented> Caution:\ndue to the implementation, the final number of selected reads may not be as\nyou expected!\nDEFAULT: False\n",
                    "id": "#macs2-callpeak.cwl/down_sample"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 26,
                        "prefix": "--extsize"
                    },
                    "doc": "The arbitrary extension size in bp. When nomodel is  true, MACS will use\nthis value as fragment size to  extend each read towards 3'' end, then pile\nthem up.  It''s exactly twice the number of obsolete SHIFTSIZE.  In previous\nlanguage, each read is moved 5''->3''  direction to middle of fragment by 1/2\nd, then  extended to both direction with 1/2 d. This is  equivalent to say each\nread is extended towards 5''->3''  into a d size fragment.EXTSIZE\nand  SHIFT can be combined when necessary. Check SHIFT  option.\nDEFAULT: 200\n",
                    "id": "#macs2-callpeak.cwl/extsize"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 40,
                        "prefix": "--fe-cutoff"
                    },
                    "doc": "When set, the value will be used to filter out peaks\nwith low fold-enrichment. Note, MACS2 use 1.0 as\npseudocount while calculating fold-enrichment.\nDEFAULT: 1.0\n",
                    "id": "#macs2-callpeak.cwl/fe_cutoff"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 23,
                        "prefix": "--fix-bimodal"
                    },
                    "doc": "Whether turn on the auto pair model process. If set, when MACS failed to\nbuild paired model, it will use the nomodel settings, the --exsize parameter\nto extend each tags towards 3'' direction. Not to use this automate fixation\nis a default behavior now.\nDEFAULT: False\n",
                    "id": "#macs2-callpeak.cwl/fix_bimodal"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#macs2-callpeak.cwl/format_mode/AUTO",
                                "#macs2-callpeak.cwl/format_mode/BAM",
                                "#macs2-callpeak.cwl/format_mode/SAM",
                                "#macs2-callpeak.cwl/format_mode/BED",
                                "#macs2-callpeak.cwl/format_mode/ELAND",
                                "#macs2-callpeak.cwl/format_mode/ELANDMULTI",
                                "#macs2-callpeak.cwl/format_mode/ELANDEXPORT",
                                "#macs2-callpeak.cwl/format_mode/BOWTIE",
                                "#macs2-callpeak.cwl/format_mode/BAMPE"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "-f"
                    },
                    "doc": "{AUTO,BAM,SAM,BED,ELAND,ELANDMULTI,ELANDEXPORT,BOWTIE,BAMPE}, --format\n{AUTO,BAM,SAM,BED,ELAND,ELANDMULTI,ELANDEXPORT,BOWTIE,BAMPE} Format of tag file,\n\"AUTO\", \"BED\" or \"ELAND\" or \"ELANDMULTI\" or \"ELANDEXPORT\" or \"SAM\" or \"BAM\"\nor \"BOWTIE\" or \"BAMPE\". The default AUTO option will let MACS decide which format\nthe file is. Note that MACS can''t detect \"BAMPE\" or \"BEDPE\" format with \"AUTO\",\nand you have to implicitly specify the format for \"BAMPE\" and \"BEDPE\".\nDEFAULT: AUTO\n",
                    "id": "#macs2-callpeak.cwl/format_mode"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "For staging in a case of trigger is set to false",
                    "id": "#macs2-callpeak.cwl/gapped_peak_file_staged"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "-g"
                    },
                    "doc": "It\u2019s the mappable genome size or effective genome size which is defined as the genome size which can be sequenced.\nBecause of the repetitive features on the chromsomes, the actual mappable genome size will be smaller than the\noriginal size, about 90% or 70% of the genome size. The default hs \u2013 2.7e9 is recommended for UCSC human hg18\nassembly. Here are all precompiled parameters for effective genome size:\n  hs:\t2.7e9\n  mm:\t1.87e9\n  ce:\t9e7\n  dm:\t1.2e8\nDEFAULT: hs\n",
                    "id": "#macs2-callpeak.cwl/genome_size"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "prefix": "--keep-dup"
                    },
                    "doc": "It controls the MACS behavior towards duplicate tags\nat the exact same location -- the same coordination\nand the same strand. The 'auto' option makes MACS\ncalculate the maximum tags at the exact same location\nbased on binomal distribution using 1e-5 as pvalue\ncutoff; and the 'all' option keeps every tags. If an\ninteger is given, at most this number of tags will be\nkept at the same location. The default is to keep one\ntag at the same location.\nDEFAULT: 1\n",
                    "id": "#macs2-callpeak.cwl/keep_dup"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 35,
                        "prefix": "--llocal"
                    },
                    "doc": "The large nearby region in basepairs to calculate\ndynamic lambda. This is used to capture the surround\nbias. If you set this to 0, MACS will skip llocal\nlambda calculation. *Note* that MACS will always\nperform a d-size local lambda calculation. The final\nlocal bias should be the maximum of the lambda value\nfrom d, slocal, and llocal size windows.\nDEFAULT: 10000.\n",
                    "id": "#macs2-callpeak.cwl/llocal"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "For staging in a case of trigger is set to false",
                    "id": "#macs2-callpeak.cwl/macs_log_staged"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 22,
                        "prefix": "-m",
                        "valueFrom": "${\n  return self.replace(/\\s+/g, ' ').split(' ');\n}\n"
                    },
                    "doc": "Select the regions within MFOLD range of high-\nconfidence enrichment ratio against background to\nbuild model. Fold-enrichment in regions must be lower\nthan upper limit, and higher than the lower limit. Use\nas \"-m 10 30\"\nDEFAULT: 5 50\n",
                    "id": "#macs2-callpeak.cwl/mfold"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "For staging in a case of trigger is set to false",
                    "id": "#macs2-callpeak.cwl/moder_r_file_staged"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "For staging in a case of trigger is set to false",
                    "id": "#macs2-callpeak.cwl/narrow_peak_file_staged"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 33,
                        "prefix": "--nolambda"
                    },
                    "doc": "If True, MACS will use fixed background lambda as local lambda for every\npeak region. Normally, MACS calculates a dynamic local lambda to reflect the\nlocal bias due to potential chromatin structure.\nDEFAULT: False\n",
                    "id": "#macs2-callpeak.cwl/nolambda"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 24,
                        "prefix": "--nomodel"
                    },
                    "doc": "Whether or not to build the shifting model. If True,  MACS will not build\nmodel. by default it means  shifting size = 100, try to set extsize to change it.\nDEFAULT: False\n",
                    "id": "#macs2-callpeak.cwl/nomodel"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 999,
                        "prefix": "-n",
                        "valueFrom": "${\n    if (self == \"\" || inputs.trigger == false){\n      return default_name();\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "The name string of the experiment. MACS will use this string NAME to create output files like \u2018NAME_peaks.xls\u2019,\n\u2018NAME_negative_peaks.xls\u2019, \u2018NAME_peaks.bed\u2019 , \u2018NAME_summits.bed\u2019, \u2018NAME_model.r\u2019 and so on.\nSo please avoid any confliction between these filenames and your existing files.\nDEFAULT: generated on the base of the treatment input\n",
                    "id": "#macs2-callpeak.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 28,
                        "prefix": "-p"
                    },
                    "doc": "Pvalue cutoff for peak detection. DEFAULT: not set.  -q, and -p are mutually\nexclusive. If pvalue cutoff is set, qvalue will not be calculated and reported\nas -1  in the final .xls file.\nDEFAULT: null\n",
                    "id": "#macs2-callpeak.cwl/p_value"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "For staging in a case of trigger is set to false",
                    "id": "#macs2-callpeak.cwl/peak_summits_file_staged"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "For staging in a case of trigger is set to false",
                    "id": "#macs2-callpeak.cwl/peak_xls_file_staged"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 27,
                        "prefix": "-q"
                    },
                    "doc": "Minimum FDR (q-value) cutoff for peak detection. -q, and\n-p are mutually exclusive.\nDEFAULT: 0.05\n",
                    "id": "#macs2-callpeak.cwl/q_value"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 30,
                        "prefix": "--ratio"
                    },
                    "doc": "When set, use a custom scaling ratio of ChIP/control\n(e.g. calculated using NCIS) for linear scaling.\nDEFAULT: null\n",
                    "id": "#macs2-callpeak.cwl/ratio"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\nif [ \"$0\" = \"true\" ]\nthen\n  ls | grep -v ${@: -1}.log | xargs rm -f\n  macs2 callpeak \"${@:1}\"\nelse\n  echo \"Skip macs2 callpeak \" ${@:1}\nfi\n",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Bash function to run MACS2 callpeak with all input parameters or skip it if trigger is false",
                    "id": "#macs2-callpeak.cwl/script"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 32,
                        "prefix": "--seed"
                    },
                    "doc": "Set the random seed while down sampling data. Must be\na non-negative integer in order to be effective.\nDEFAULT: null\n",
                    "id": "#macs2-callpeak.cwl/seed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 25,
                        "prefix": "--shift"
                    },
                    "doc": "(NOT the legacy --shiftsize option!) The arbitrary shift in bp. Use discretion\nwhile setting it other than default value. When NOMODEL is set, MACS will use\nthis value to move cutting ends (5'') towards 5''->3'' direction then apply\nEXTSIZE to extend them to fragments. When this value is negative, ends will\nbe moved toward 3''->5'' direction. Recommended to keep it as default 0 for\nChIP-Seq datasets, or -1 * half of EXTSIZE together with EXTSIZE option for\ndetecting enriched cutting loci such as certain DNAseI-Seq datasets. Note, you\ncan''t set values other than 0 if format is BAMPE for paired-end data.\nDEFAULT: 0\n",
                    "id": "#macs2-callpeak.cwl/shift"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 34,
                        "prefix": "--slocal"
                    },
                    "doc": "The small nearby region in basepairs to calculate\ndynamic lambda. This is used to capture the bias near\nthe peak summit region. Invalid if there is no control\ndata. If you set this to 0, MACS will skip slocal\nlambda calculation. *Note* that MACS will always\nperform a d-size local lambda calculation. The final\nlocal bias should be the maximum of the lambda value\nfrom d, slocal, and llocal size windows.\nDEFAULT: 1000\n",
                    "id": "#macs2-callpeak.cwl/slocal"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 19,
                        "prefix": "--SPMR"
                    },
                    "doc": "If True, MACS will save signal per million reads for fragment pileup profiles.\nRequire --bdg to be set.\nDEFAULT: False\n",
                    "id": "#macs2-callpeak.cwl/spmr"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 29,
                        "prefix": "--to-large"
                    },
                    "doc": "When set, scale the small sample up to the bigger sample. By default, the\nbigger dataset will be scaled down towards the smaller dataset, which will lead\nto smaller p/qvalues and more specific results. Keep in mind that scaling down\nwill bring down background noise more.\nDEFAULT: False\n",
                    "id": "#macs2-callpeak.cwl/to_large"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 18,
                        "prefix": "--trackline"
                    },
                    "doc": "Tells MACS to include trackline with bedGraph files. To include this trackline\nwhile displaying bedGraph at UCSC genome browser, can show name and description\nof the file as well. Require -B to be set.\nDEFAULT: False\n",
                    "id": "#macs2-callpeak.cwl/trackline"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "For staging in a case of trigger is set to false",
                    "id": "#macs2-callpeak.cwl/treat_pileup_bdg_file_staged"
                },
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "-t"
                    },
                    "doc": "This is the only REQUIRED parameter for MACS. File can be in any supported format specified by \u2013format option.\nCheck \u2013format for detail. If you have more than one alignment files, you can specify them as `-t A B C`.\nMACS will pool up all these files together.\n",
                    "id": "#macs2-callpeak.cwl/treatment_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "position": 2,
                        "valueFrom": "${return self?\"true\":\"false\"}\n"
                    },
                    "doc": "If true - run MACS2, if false - return staged files",
                    "id": "#macs2-callpeak.cwl/trigger"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 20,
                        "prefix": "--tsize"
                    },
                    "doc": "Tag size. This will overide the auto detected tag size.\nDEFAULT: False\n",
                    "id": "#macs2-callpeak.cwl/tsize"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 41,
                        "prefix": "--verbose"
                    },
                    "doc": "Log level\n",
                    "id": "#macs2-callpeak.cwl/verbose"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${ if (inputs.output_prefix == \"\" || inputs.trigger == false){ return default_name(inputs.broad_peak_file_staged, '_macs_peaks.broadPeak'); } else { return inputs.output_prefix + '_peaks.broadPeak'; } }"
                    },
                    "id": "#macs2-callpeak.cwl/broad_peak_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${ if (inputs.output_prefix == \"\" || inputs.trigger == false){ return default_name(inputs.control_lambda_bdg_file_staged, '_macs_control_lambda.bdg'); } else { return inputs.output_prefix + '_control_lambda.bdg'; } }"
                    },
                    "id": "#macs2-callpeak.cwl/control_lambda_bdg_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${ if (inputs.output_prefix == \"\" || inputs.trigger == false){ return default_name(inputs.gapped_peak_file_staged, '_macs_peaks.gappedPeak'); } else { return inputs.output_prefix + '_peaks.gappedPeak'; } }"
                    },
                    "id": "#macs2-callpeak.cwl/gapped_peak_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n    if (inputs.output_prefix == \"\" || inputs.trigger == false){\n      return default_name(null, '_macs.log');\n    } else {\n      return inputs.output_prefix + '.log';\n    }\n}\n"
                    },
                    "id": "#macs2-callpeak.cwl/macs_log"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${ if (inputs.output_prefix == \"\" || inputs.trigger == false){ return default_name(inputs.moder_r_file_staged, '_macs_model.r'); } else { return inputs.output_prefix + '_model.r'; } }"
                    },
                    "id": "#macs2-callpeak.cwl/moder_r_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${ if (inputs.output_prefix == \"\" || inputs.trigger == false){ return default_name(inputs.narrow_peak_file_staged, '_macs_peaks.narrowPeak'); } else { return inputs.output_prefix + '_peaks.narrowPeak'; } }"
                    },
                    "id": "#macs2-callpeak.cwl/narrow_peak_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${ if (inputs.output_prefix == \"\" || inputs.trigger == false){ return default_name(inputs.peak_summits_file_staged, '_macs_summits.bed'); } else { return inputs.output_prefix + '_summits.bed'; } }"
                    },
                    "id": "#macs2-callpeak.cwl/peak_summits_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${ if (inputs.output_prefix == \"\" || inputs.trigger == false){ return default_name(inputs.peak_xls_file_staged, '_macs_peaks.xls'); } else { return inputs.output_prefix + '_peaks.xls'; } }"
                    },
                    "id": "#macs2-callpeak.cwl/peak_xls_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${ if (inputs.output_prefix == \"\" || inputs.trigger == false){ return default_name(inputs.treat_pileup_bdg_file_staged, '_macs_treat_pileup.bdg'); } else { return inputs.output_prefix + '_treat_pileup.bdg'; } }"
                    },
                    "id": "#macs2-callpeak.cwl/treat_pileup_bdg_file"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "arguments": [
                {
                    "valueFrom": "${ if (inputs.output_prefix == \"\" || inputs.trigger == false ){ return ' 2>> ' + default_name(null, '_macs.log'); } else { return ' 2>> ' + inputs.output_prefix + '.log'; } }",
                    "position": 100000,
                    "shellQuote": false
                }
            ],
            "doc": "Tool is used to perform peak calling using MACS2.\nInput Trigger (default: true) allows to skip all calculation and return\nall input files unchanged. To set files to be returned in case of Trigger == false,\nuse the following inputs:\n  peak_xls_file_staged:\n  narrow_peak_file_staged:\n  broad_peak_file_staged:\n  gapped_peak_file_staged:\n  peak_summits_file_staged:\n  moder_r_file_staged:\n  treat_pileup_bdg_file_staged:\n  control_lambda_bdg_file_staged:\n",
            "id": "#macs2-callpeak.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#macs2-metadata.yaml",
                "http://schema.org/name": "MACS2",
                "http://schema.org/about": "With the improvement of sequencing techniques, chromatin immunoprecipitation followed by high throughput\nsequencing (ChIP-Seq) is getting popular to study genome-wide protein-DNA interactions. To address the\nlack of powerful ChIP-Seq analysis method, we present a novel algorithm, named Model-based Analysis\nof ChIP-Seq (MACS), for identifying transcript factor binding sites. MACS captures the influence of\ngenome complexity to evaluate the significance of enriched ChIP regions, and MACS improves the spatial\nresolution of binding sites through combining the information of both sequencing tag position and\norientation. MACS can be easily used for ChIP-Seq data alone, or with control sample with the increase\nof specificity.\n",
                "http://schema.org/url": "http://liulab.dfci.harvard.edu/MACS/",
                "http://schema.org/codeRepository": "https://github.com/taoliu/MACS",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/BSD-3-Clause"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "2.1.1.20160309",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "Python",
                "http://schema.org/publication": [
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#macs2-metadata.yaml/10.1186/gb-2008-9-9-r137",
                        "datePublished": "17 September 2008",
                        "http://schema.org/name": "Model-based analysis of ChIP-Seq (MACS)",
                        "http://schema.org/author": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Zhang Y"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Liu T"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Meyer CA"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Eeckhoute J"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Johnson DS"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Bernstein BE"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Nusbaum C"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Myers RM"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Brown M"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Li W"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Liu XS"
                            }
                        ],
                        "http://schema.org/url": "https://genomebiology.biomedcentral.com/articles/10.1186/gb-2008-9-9-r137"
                    }
                ],
                "http://schema.org/discussionUrl": [
                    "https://groups.google.com/forum/#!forum/macs-announcement",
                    "https://github.com/taoliu/MACS/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Xiaole Shirley Liu's Lab",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Yong Zhang",
                                "http://schema.org/description": "Main author"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Tao Liu",
                                "http://schema.org/description": "Main author"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "macs2-callpeak",
            "http://schema.org/downloadUrl": "https://github.com/Barski-lab/workflows/tree/master/tools/macs2-callpeak.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "usage: macs2 callpeak [-h] -t TFILE [TFILE ...] [-c [CFILE [CFILE ...]]]\n                      [-f {AUTO,BAM,SAM,BED,ELAND,ELANDMULTI,ELANDEXPORT,BOWTIE,BAMPE,BEDPE}]\n                      [-g GSIZE] [--keep-dup KEEPDUPLICATES]\n                      [--buffer-size BUFFER_SIZE] [--outdir OUTDIR] [-n NAME]\n                      [-B] [--verbose VERBOSE] [--trackline] [--SPMR]\n                      [-s TSIZE] [--bw BW] [-m MFOLD MFOLD] [--fix-bimodal]\n                      [--nomodel] [--shift SHIFT] [--extsize EXTSIZE]\n                      [-q QVALUE | -p PVALUE] [--to-large] [--ratio RATIO]\n                      [--down-sample] [--seed SEED] [--tempdir TEMPDIR]\n                      [--nolambda] [--slocal SMALLLOCAL] [--llocal LARGELOCAL]\n                      [--broad] [--broad-cutoff BROADCUTOFF]\n                      [--cutoff-analysis] [--call-summits]\n                      [--fe-cutoff FECUTOFF]\n\noptional arguments:\n  -h, --help            show this help message and exit\n\nInput files arguments:\n  -t TFILE [TFILE ...], --treatment TFILE [TFILE ...]\n                        ChIP-seq treatment file. If multiple files are given\n                        as '-t A B C', then they will all be read and pooled\n                        together. REQUIRED.\n  -c [CFILE [CFILE ...]], --control [CFILE [CFILE ...]]\n                        Control file. If multiple files are given as '-c A B\n                        C', they will be pooled to estimate ChIP-seq\n                        background noise.\n  -f {AUTO,BAM,SAM,BED,ELAND,ELANDMULTI,ELANDEXPORT,BOWTIE,BAMPE,BEDPE}, --format {AUTO,BAM,SAM,BED,ELAND,ELANDMULTI,ELANDEXPORT,BOWTIE,BAMPE,BEDPE}\n                        Format of tag file, \"AUTO\", \"BED\" or \"ELAND\" or\n                        \"ELANDMULTI\" or \"ELANDEXPORT\" or \"SAM\" or \"BAM\" or\n                        \"BOWTIE\" or \"BAMPE\" or \"BEDPE\". The default AUTO\n                        option will let MACS decide which format (except for\n                        BAMPE and BEDPE which should be implicitly set) the\n                        file is. Please check the definition in README. Please\n                        note that if the format is set as BAMPE or BEDPE,\n                        MACS2 will call its special Paired-end mode to call\n                        peaks by piling up the actual ChIPed fragments defined\n                        by both aligned ends, instead of predicting the\n                        fragment size first and extending reads. Also please\n                        note that the BEDPE only contains three columns, and\n                        is NOT the same BEDPE format used by BEDTOOLS.\n                        DEFAULT: \"AUTO\"\n  -g GSIZE, --gsize GSIZE\n                        Effective genome size. It can be 1.0e+9 or 1000000000,\n                        or shortcuts:'hs' for human (2.7e9), 'mm' for mouse\n                        (1.87e9), 'ce' for C. elegans (9e7) and 'dm' for\n                        fruitfly (1.2e8), Default:hs\n  --keep-dup KEEPDUPLICATES\n                        It controls the MACS behavior towards duplicate tags\n                        at the exact same location -- the same coordination\n                        and the same strand. The 'auto' option makes MACS\n                        calculate the maximum tags at the exact same location\n                        based on binomal distribution using 1e-5 as pvalue\n                        cutoff; and the 'all' option keeps every tags. If an\n                        integer is given, at most this number of tags will be\n                        kept at the same location. Note, if you've used\n                        samtools or picard to flag reads as 'PCR/Optical\n                        duplicate' in bit 1024, MACS2 will still read them\n                        although the reads may be decided by MACS2 as\n                        duplicate later. The default is to keep one tag at the\n                        same location. Default: 1\n  --buffer-size BUFFER_SIZE\n                        Buffer size for incrementally increasing internal\n                        array size to store reads alignment information. In\n                        most cases, you don't have to change this parameter.\n                        However, if there are large number of\n                        chromosomes/contigs/scaffolds in your alignment, it's\n                        recommended to specify a smaller buffer size in order\n                        to decrease memory usage (but it will take longer time\n                        to read alignment files). Minimum memory requested for\n                        reading an alignment file is about # of CHROMOSOME *\n                        BUFFER_SIZE * 2 Bytes. DEFAULT: 100000\n\nOutput arguments:\n  --outdir OUTDIR       If specified all output files will be written to that\n                        directory. Default: the current working directory\n  -n NAME, --name NAME  Experiment name, which will be used to generate output\n                        file names. DEFAULT: \"NA\"\n  -B, --bdg             Whether or not to save extended fragment pileup, and\n                        local lambda tracks (two files) at every bp into a\n                        bedGraph file. DEFAULT: False\n  --verbose VERBOSE     Set verbose level of runtime message. 0: only show\n                        critical message, 1: show additional warning message,\n                        2: show process information, 3: show debug messages.\n                        DEFAULT:2\n  --trackline           Tells MACS to include trackline with bedGraph files.\n                        To include this trackline while displaying bedGraph at\n                        UCSC genome browser, can show name and description of\n                        the file as well. However my suggestion is to convert\n                        bedGraph to bigWig, then show the smaller and faster\n                        binary bigWig file at UCSC genome browser, as well as\n                        downstream analysis. Require -B to be set. Default:\n                        Not include trackline.\n  --SPMR                If True, MACS will save signal per million reads for\n                        fragment pileup profiles. Require -B to be set.\n                        Default: False\n\nShifting model arguments:\n  -s TSIZE, --tsize TSIZE\n                        Tag size. This will override the auto detected tag\n                        size. DEFAULT: Not set\n  --bw BW               Band width for picking regions to compute fragment\n                        size. This value is only used while building the\n                        shifting model. DEFAULT: 300\n  -m MFOLD MFOLD, --mfold MFOLD MFOLD\n                        Select the regions within MFOLD range of high-\n                        confidence enrichment ratio against background to\n                        build model. Fold-enrichment in regions must be lower\n                        than upper limit, and higher than the lower limit. Use\n                        as \"-m 10 30\". DEFAULT:5 50\n  --fix-bimodal         Whether turn on the auto pair model process. If set,\n                        when MACS failed to build paired model, it will use\n                        the nomodel settings, the --exsize parameter to extend\n                        each tags towards 3' direction. Not to use this\n                        automate fixation is a default behavior now. DEFAULT:\n                        False\n  --nomodel             Whether or not to build the shifting model. If True,\n                        MACS will not build model. by default it means\n                        shifting size = 100, try to set extsize to change it.\n                        DEFAULT: False\n  --shift SHIFT         (NOT the legacy --shiftsize option!) The arbitrary\n                        shift in bp. Use discretion while setting it other\n                        than default value. When NOMODEL is set, MACS will use\n                        this value to move cutting ends (5') towards 5'->3'\n                        direction then apply EXTSIZE to extend them to\n                        fragments. When this value is negative, ends will be\n                        moved toward 3'->5' direction. Recommended to keep it\n                        as default 0 for ChIP-Seq datasets, or -1 * half of\n                        EXTSIZE together with EXTSIZE option for detecting\n                        enriched cutting loci such as certain DNAseI-Seq\n                        datasets. Note, you can't set values other than 0 if\n                        format is BAMPE or BEDPE for paired-end data. DEFAULT:\n                        0.\n  --extsize EXTSIZE     The arbitrary extension size in bp. When nomodel is\n                        true, MACS will use this value as fragment size to\n                        extend each read towards 3' end, then pile them up.\n                        It's exactly twice the number of obsolete SHIFTSIZE.\n                        In previous language, each read is moved 5'->3'\n                        direction to middle of fragment by 1/2 d, then\n                        extended to both direction with 1/2 d. This is\n                        equivalent to say each read is extended towards 5'->3'\n                        into a d size fragment. DEFAULT: 200. EXTSIZE and\n                        SHIFT can be combined when necessary. Check SHIFT\n                        option.\n\nPeak calling arguments:\n  -q QVALUE, --qvalue QVALUE\n                        Minimum FDR (q-value) cutoff for peak detection.\n                        DEFAULT: 0.05. -q, and -p are mutually exclusive.\n  -p PVALUE, --pvalue PVALUE\n                        Pvalue cutoff for peak detection. DEFAULT: not set.\n                        -q, and -p are mutually exclusive. If pvalue cutoff is\n                        set, qvalue will not be calculated and reported as -1\n                        in the final .xls file.\n  --to-large            When set, scale the small sample up to the bigger\n                        sample. By default, the bigger dataset will be scaled\n                        down towards the smaller dataset, which will lead to\n                        smaller p/qvalues and more specific results. Keep in\n                        mind that scaling down will bring down background\n                        noise more. DEFAULT: False\n  --ratio RATIO         When set, use a custom scaling ratio of ChIP/control\n                        (e.g. calculated using NCIS) for linear scaling.\n                        DEFAULT: ingore\n  --down-sample         When set, random sampling method will scale down the\n                        bigger sample. By default, MACS uses linear scaling.\n                        Warning: This option will make your result unstable\n                        and irreproducible since each time, random reads would\n                        be selected. Consider to use 'randsample' script\n                        instead. <not implmented>If used together with --SPMR,\n                        1 million unique reads will be randomly picked.</not\n                        implemented> Caution: due to the implementation, the\n                        final number of selected reads may not be as you\n                        expected! DEFAULT: False\n  --seed SEED           Set the random seed while down sampling data. Must be\n                        a non-negative integer in order to be effective.\n                        DEFAULT: not set\n  --tempdir TEMPDIR     Optional directory to store temp files. DEFAULT: /tmp\n  --nolambda            If True, MACS will use fixed background lambda as\n                        local lambda for every peak region. Normally, MACS\n                        calculates a dynamic local lambda to reflect the local\n                        bias due to potential chromatin structure.\n  --slocal SMALLLOCAL   The small nearby region in basepairs to calculate\n                        dynamic lambda. This is used to capture the bias near\n                        the peak summit region. Invalid if there is no control\n                        data. If you set this to 0, MACS will skip slocal\n                        lambda calculation. *Note* that MACS will always\n                        perform a d-size local lambda calculation. The final\n                        local bias should be the maximum of the lambda value\n                        from d, slocal, and llocal size windows. DEFAULT: 1000\n  --llocal LARGELOCAL   The large nearby region in basepairs to calculate\n                        dynamic lambda. This is used to capture the surround\n                        bias. If you set this to 0, MACS will skip llocal\n                        lambda calculation. *Note* that MACS will always\n                        perform a d-size local lambda calculation. The final\n                        local bias should be the maximum of the lambda value\n                        from d, slocal, and llocal size windows. DEFAULT:\n                        10000.\n  --broad               If set, MACS will try to call broad peaks by linking\n                        nearby highly enriched regions. The linking region is\n                        controlled by another cutoff through --linking-cutoff.\n                        The maximum linking region length is 4 times of d from\n                        MACS. DEFAULT: False\n  --broad-cutoff BROADCUTOFF\n                        Cutoff for broad region. This option is not available\n                        unless --broad is set. If -p is set, this is a pvalue\n                        cutoff, otherwise, it's a qvalue cutoff. DEFAULT: 0.1\n  --cutoff-analysis     While set, MACS2 will analyze number or total length\n                        of peaks that can be called by different p-value\n                        cutoff then output a summary table to help user decide\n                        a better cutoff. The table will be saved in\n                        NAME_cutoff_analysis.txt file. Note, minlen and maxgap\n                        may affect the results. WARNING: May take ~30 folds\n                        longer time to finish. DEFAULT: False\n\nPost-processing options:\n  --call-summits        If set, MACS will use a more sophisticated signal\n                        processing approach to find subpeak summits in each\n                        enriched peak region. DEFAULT: False\n  --fe-cutoff FECUTOFF  When set, the value will be used to filter out peaks\n                        with low fold-enrichment. Note, MACS2 use 1.0 as\n                        pseudocount while calculating fold-enrichment.\n                        DEFAULT: 1.0\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var get_output_filename = function() { if (inputs.output_filename) { return inputs.output_filename; } var root = inputs.bowtie_log.basename.split('.').slice(0,-1).join('.'); var ext = \".stat\"; return (root == \"\")?inputs.bowtie_log.basename+ext:root+ext; };",
                        "var get_formatted_output_filename = function() { if (inputs.formatted_output_filename) { return inputs.formatted_output_filename; } var root = inputs.bowtie_log.basename.split('.').slice(0,-1).join('.'); var ext = \"_stats.tsv\"; return (root == \"\")?inputs.bowtie_log.basename+ext:root+ext; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "Log file from Bowtie",
                    "id": "#python-get-stat-chipseq.cwl/bowtie_log"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "valueFrom": "$(get_formatted_output_filename())"
                    },
                    "default": "",
                    "doc": "Name for generated formatted output file",
                    "id": "#python-get-stat-chipseq.cwl/formatted_output_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "valueFrom": "$(get_output_filename())"
                    },
                    "default": "",
                    "doc": "Name for generated output file",
                    "id": "#python-get-stat-chipseq.cwl/output_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 7
                    },
                    "doc": "Log file from samtools rmdup",
                    "id": "#python-get-stat-chipseq.cwl/rmdup_log"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/usr/bin/env python\nimport sys, re\nTOTAL, ALIGNED, SUPPRESSED, USED = 100, 80, 0, 0\nwith open(sys.argv[1], 'r') as bowtie_log:\n  for line in bowtie_log:\n    if 'processed:' in line:\n      TOTAL = int(line.split('processed:')[1])\n    if 'alignment:' in line:\n      ALIGNED = int(line.split('alignment:')[1].split()[0])\n    if 'due to -m:' in line:\n      SUPPRESSED = int(line.split('due to -m:')[1].split()[0])\nUSED = ALIGNED\nwith open(sys.argv[2], 'r') as rmdup_log:\n  for line in rmdup_log:\n    if '/' in line and 'Skip' not in line:\n      splt = line.split('/')\n      USED = int((splt[1].split('='))[0].strip()) - int((splt[0].split(']'))[1].strip())\nwith open(sys.argv[3], 'w') as fo:\n    fo.write(str(TOTAL) + \" \" + str(ALIGNED) + \" \" + str(SUPPRESSED) + \" \" + str(USED))\nwith open(sys.argv[4], 'w') as fof:\n    fof.write(\"Tags total\\tMapped\\tMulti-mapped\\tUnmapped\\tDuplicates\\n\")\n    fof.write(str(TOTAL) + \"\\t\" + str(USED) + \"\\t\" + str(SUPPRESSED) + \"\\t\" + str(TOTAL-ALIGNED-SUPPRESSED) + \"\\t\" + str(ALIGNED-USED) + \"\\n\")\n",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Python script to get TOTAL, ALIGNED, SUPPRESSED, USED values from log files",
                    "id": "#python-get-stat-chipseq.cwl/script"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(get_formatted_output_filename())"
                    },
                    "id": "#python-get-stat-chipseq.cwl/formatted_output_file"
                },
                {
                    "type": "int",
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "$(get_output_filename())",
                        "outputEval": "$(parseInt(self[0].contents.split(' ')[1]))"
                    },
                    "id": "#python-get-stat-chipseq.cwl/mapped_reads"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(get_output_filename())"
                    },
                    "id": "#python-get-stat-chipseq.cwl/output_file"
                },
                {
                    "type": "int",
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "$(get_output_filename())",
                        "outputEval": "$(parseInt(self[0].contents.split(' ')[2]))"
                    },
                    "id": "#python-get-stat-chipseq.cwl/suppressed_reads"
                },
                {
                    "type": "int",
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "$(get_output_filename())",
                        "outputEval": "$(parseInt(self[0].contents.split(' ')[0]))"
                    },
                    "id": "#python-get-stat-chipseq.cwl/total_reads"
                },
                {
                    "type": "int",
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "$(get_output_filename())",
                        "outputEval": "$(parseInt(self[0].contents.split(' ')[3]))"
                    },
                    "id": "#python-get-stat-chipseq.cwl/used_reads"
                }
            ],
            "baseCommand": [
                "python",
                "-c"
            ],
            "doc": "Tool processes and combines log files generated by Bowtie aligner and samtools rmdup.\n\n`get_output_filename` function returns output filename equal to `output_filename` (if this input is provided) or\ngenerated on the base of bowtie log basename with `.stat` extension.\n\n`get_formatted_output_filename` function returns output filename equal to `formatted_output_filename` (if input is provided) or\ngenerated on the base of STAR log basename with `_stats.tsv` extension.\n",
            "id": "#python-get-stat-chipseq.cwl",
            "http://schema.org/name": "python-get-stat-chipseq",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/python-get-stat-chipseq.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Runs python code from the script input\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var ext = function() { if (inputs.csi && !inputs.bai){ return '.csi'; } else { return '.bai'; } };",
                        "var default_bam = function() { if (inputs.trigger == true){ return inputs.sort_input.location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.')+\".bam\"; } else { return inputs.sort_input.location.split('/').slice(-1)[0]; } };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/samtools:v1.4"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Generate BAI-format index for BAM files [default]. If input isn't cram.\n",
                    "id": "#samtools-sort-index.cwl/bai"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\nif [ \"$0\" = \"true\" ]\nthen\n  echo \"Run: samtools index \" ${@:1}\n  samtools index \"${@:1}\"\nelse\n  echo \"Skip samtools index \" ${@:1}\nfi\n",
                    "inputBinding": {
                        "position": 20
                    },
                    "doc": "Bash function to run samtools index with all input parameters or skip it if trigger is false\n",
                    "id": "#samtools-sort-index.cwl/bash_script_index"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\nif [ \"$0\" = \"true\" ]\nthen\n  echo \"Run: samtools sort \" ${@:1}\n  samtools sort \"${@:1}\"\nelse\n  echo \"Skip samtools sort \" ${@:1}\n  SOURCE=${@:(-1):1}\n  TARGET=$(basename \"$SOURCE\")\n  cp $SOURCE $TARGET\nfi\n",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Bash function to run samtools sort with all input parameters or skip it if trigger is false\n",
                    "id": "#samtools-sort-index.cwl/bash_script_sort"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Generate CSI-format index for BAM files. If input isn't cram.\n",
                    "id": "#samtools-sort-index.cwl/csi"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 24,
                        "prefix": "-m"
                    },
                    "doc": "Set minimum interval size for CSI indices to 2^INT [14]\n",
                    "id": "#samtools-sort-index.cwl/csi_interval"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "-l"
                    },
                    "doc": "SORT: desired compression level for the final output file, ranging from 0 (uncompressed)\nor 1 (fastest but minimal compression) to 9 (best compression but slowest to write),\nsimilarly to gzip(1)'s compression level setting.\nIf -l is not used, the default compression level will apply.\n",
                    "id": "#samtools-sort-index.cwl/sort_compression_level"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 16
                    },
                    "doc": "Input only in.sam|in.bam|in.cram. Optionally could be supplemented with index file in secondaryFiles\n",
                    "id": "#samtools-sort-index.cwl/sort_input"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "-o",
                        "valueFrom": "${\n    if (self == \"\" || inputs.trigger == false){\n      return default_bam();\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Write the final sorted output to FILE. Only out.bam|out.cram.\nIf output file extension is set to SAM, tool will fail on the index step\n",
                    "id": "#samtools-sort-index.cwl/sort_output_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Set number of sorting and compression threads [1] (Only for sorting)\n",
                    "id": "#samtools-sort-index.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "doc": "If true - run samtools, if false - return sort_input and optional index file in secondaryFiles.\n",
                    "id": "#samtools-sort-index.cwl/trigger"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n    if (inputs.sort_output_filename == \"\" || inputs.trigger == false){\n      return default_bam();\n    } else {\n      return inputs.sort_output_filename;\n    }\n}\n"
                    },
                    "secondaryFiles": "${ if (inputs.trigger == true){ return self.basename + ext(); } else { return inputs.sort_input.secondaryFiles?inputs.sort_input.secondaryFiles:\"null\"; } }",
                    "id": "#samtools-sort-index.cwl/bam_bai_pair"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "arguments": [
                {
                    "valueFrom": "${ return inputs.trigger ? \"true\" : \"false\" }\n",
                    "position": 6
                },
                {
                    "valueFrom": "bam",
                    "position": 13,
                    "prefix": "-O"
                },
                {
                    "valueFrom": "$(inputs.threads?inputs.threads:1)",
                    "position": 15,
                    "prefix": "-@"
                },
                {
                    "valueFrom": ";",
                    "position": 17,
                    "shellQuote": false
                },
                {
                    "valueFrom": "bash",
                    "position": 18
                },
                {
                    "valueFrom": "-c",
                    "position": 19
                },
                {
                    "valueFrom": "${ return inputs.trigger ? \"true\" : \"false\" }\n",
                    "position": 21
                },
                {
                    "valueFrom": "$(inputs.bai?'-b':inputs.csi?'-c':[])",
                    "position": 23
                },
                {
                    "valueFrom": "$(inputs.threads?inputs.threads:1)",
                    "position": 25,
                    "prefix": "-@"
                },
                {
                    "valueFrom": "${\n    if (inputs.sort_output_filename == \"\" || inputs.trigger == false){\n      return default_bam();\n    } else {\n      return inputs.sort_output_filename;\n    }\n}\n",
                    "position": 26
                },
                {
                    "valueFrom": "${\n    if (inputs.sort_output_filename == \"\" || inputs.trigger == false){\n      return default_bam() + ext();\n    } else {\n      return inputs.sort_output_filename + ext();\n    }\n}\n",
                    "position": 27
                }
            ],
            "doc": "Tool to sort and index input BAM/SAM/CRAM.\nIf input `trigger` is set to `true` or isn't set at all (`true` is used by default), run `samtools sort` and\n`samtools index`, return sorted BAM and BAI/CSI index file.\nIf input `trigger` is set to `false`, return unchanged `sort_input` (BAM/SAM/CRAM) and index (BAI/CSI, if provided in\n`secondaryFiles`) files.\n\nTrigger logic is implemented in two bash scripts set by default as `bash_script_sort` and `bash_script_index` inputs.\nFor both of then, if the first argument $0 (which is `trigger` input) is true, run `samtools sort/index` with the rest\nof the arguments. If $0 is not true, skip `samtools sort/index` and return `sort_input` and `secondaryFiles`\n(if provided).\n\nInput `trigger` is Boolean, but returns String, because of `valueFrom` field. The `valueFrom` is used, because if `trigger`\nis false, cwl-runner doesn't append this argument at all to the the `baseCommand` - new feature of CWL v1.0.2. Alternatively,\n`prefix` field could be used, but it causes changing in script logic.\n\nIf using `sort_output_filename`, the output file extension should be `*.bam`, because `samtools sort` defines the output\nfile format on the base of the file extension. If `*.sam` is sed as output filename, it cannot be usefully indexed\nby `samtools index`.\n\n`default_bam` function is used to generate output filename for `samtools sort` if input `sort_output_filename` is not\nset or when `trigger` is false and we need to return `sort_input` and `secondaryFiles` (if provided) files. Output\nfilename is generated on the base of `sort_input` basename with `.bam` extension by default.\n\n`ext` function is used to return the index file extension (BAI/CSI) based on `csi` and `bai` inputs according to the\nfollowing logic\n  `csi` &&  `bai`  => BAI\n !`csi` && !`bai ` => BAI\n  `csi` && !`bai ` => CSI\n",
            "id": "#samtools-sort-index.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#samtools-metadata.yaml",
                "http://schema.org/name": "samtools",
                "http://schema.org/about": "A suite of programs for interacting with high-throughput sequencing data. It consists of three separate repositories: Samtools (Reading/writing/editing/indexing/viewing SAM/BAM/CRAM format), BCFtools (Reading/writing BCF2/VCF/gVCF files and calling/filtering/summarising SNP and short indel sequence variants) and HTSlib (A C library for reading/writing high-throughput sequencing data).\n",
                "http://schema.org/url": "http://www.htslib.org/",
                "http://schema.org/codeRepository": "https://github.com/samtools/samtools.git",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/MIT",
                    "https://opensource.org/licenses/BSD-3-Clause"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "1.4",
                    "http://schema.org/applicationCategory": "commandline tool"
                },
                "http://schema.org/programmingLanguage": "C, Perl",
                "http://schema.org/publication": [
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#btr509",
                        "http://schema.org/name": "(Li, 2011) A statistical framework for SNP calling, mutation discovery, association mapping and population genetical parameter estimation from sequencing data. Bioinformatics.",
                        "http://schema.org/url": "http://www.ncbi.nlm.nih.gov/pubmed/21903627"
                    },
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#btr076",
                        "http://schema.org/name": "(Li, 2011) Improving SNP discovery by base alignment quality. Bioinformatics.",
                        "http://schema.org/url": "http://www.ncbi.nlm.nih.gov/pubmed/21320865"
                    },
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#btp352",
                        "http://schema.org/name": "(Li et al., 2009) The Sequence Alignment/Map format and SAMtools. Bioinformatics.",
                        "http://schema.org/url": "http://www.ncbi.nlm.nih.gov/pubmed/19505943"
                    }
                ],
                "http://schema.org/discussionUrl": [
                    "https://lists.sourceforge.net/lists/listinfo/samtools-help",
                    "https://lists.sourceforge.net/lists/listinfo/samtools-devel"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Sanger Institute",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Heng Li",
                                "http://schema.org/description": "wrote most of the initial source codes of SAMtools and various converters."
                            }
                        ]
                    },
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Broad Institute",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Bob Handsaker",
                                "http://schema.org/description": "A major contributor to the\nSAM/BAM specification. He designed and implemented the BGZF format, the\nunderlying indexable compression format for the BAM format. BGZF does\nnot support arithmetic between file offsets.\n"
                            }
                        ]
                    },
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Beijing Genome Institute",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Jue Ruan",
                                "http://schema.org/description": "Designed and implemented the\nRAZF format, an alternative indexable compression format. RAZF is no longer\nused by or provided with SAMtools. Source code remains available in older\nSAMtools 0.1.x releases and from the standalone branch in the repository.\n"
                            }
                        ]
                    },
                    {
                        "class": "http://schema.org/Person",
                        "http://schema.org/name": "Colin Hercus",
                        "http://schema.org/description": "updated novo2sam.pl to support gapped alignment by novoalign."
                    },
                    {
                        "class": "http://schema.org/Person",
                        "http://schema.org/name": "Petr Danecek",
                        "http://schema.org/description": "contributed the header parsing library sam_header.c and sam2vcf.pl script."
                    }
                ]
            },
            "http://schema.org/name": "samtools-sort-index",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/samtools-sort-index.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage: samtools sort [options...] [in.bam]\nOptions:\n  -l INT     Set compression level, from 0 (uncompressed) to 9 (best)\n  -m INT     Set maximum memory per thread; suffix K/M/G recognized [768M]\n  -n         Sort by read name\n  -o FILE    Write final output to FILE rather than standard output\n  -T PREFIX  Write temporary files to PREFIX.nnnn.bam\n      --input-fmt-option OPT[=VAL]\n               Specify a single input file format option in the form\n               of OPTION or OPTION=VALUE\n  -O, --output-fmt FORMAT[,OPT[=VAL]]...\n               Specify output format (SAM, BAM, CRAM)\n      --output-fmt-option OPT[=VAL]\n               Specify a single output file format option in the form\n               of OPTION or OPTION=VALUE\n      --reference FILE\n               Reference sequence FASTA FILE [null]\n  -@, --threads INT\n               Number of additional threads to use [0]\n\nUsage: samtools index [-bc] [-m INT] <in.bam> [out.index]\nOptions:\n  -b       Generate BAI-format index for BAM files [default]\n  -c       Generate CSI-format index for BAM files\n  -m INT   Set minimum interval size for CSI indices to 2^INT [14]\n  -@ INT   Sets the number of threads [none]\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { var basename = inputs.bedgraph_file.location.split('/').slice(-1)[0]; var root = basename.split('.').slice(0,-1).join('.'); var ext = \".bigWig\"; return (root == \"\")?basename+ext:root+ext; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/ucscuserapps:v358"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 10
                    },
                    "doc": "Four column bedGraph file: <chrom> <start> <end> <value>\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/bedgraph_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "separate": false,
                        "position": 7,
                        "prefix": "-blockSize="
                    },
                    "doc": "Number of items to bundle in r-tree.  Default 256\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/block_size"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 11
                    },
                    "doc": "Two-column chromosome length file: <chromosome name> <size in bases>\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/chrom_length_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "separate": false,
                        "position": 6,
                        "prefix": "-itemsPerSlot="
                    },
                    "doc": "Number of data points bundled at lowest level. Default 1024\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/items_per_slot"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename();\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "If set, writes the output bigWig file to output_filename,\notherwise generates filename from default_output_filename()\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-unc"
                    },
                    "doc": "Disable compression\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/unc"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename();\n    } else {\n      return inputs.output_filename;\n    }\n}\n"
                    },
                    "id": "#ucsc-bedgraphtobigwig.cwl/bigwig_file"
                }
            ],
            "baseCommand": [
                "bedGraphToBigWig"
            ],
            "doc": "Tool converts bedGraph to bigWig file.\n\n`default_output_filename` function returns filename for generated bigWig if `output_filename` is not provided.\nDefault filename is generated on the base of `bedgraph_file` basename with the updated to `*.bigWig` extension.\n",
            "id": "#ucsc-bedgraphtobigwig.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#ucsc-metadata.yaml",
                "http://schema.org/name": "UCSC userApps",
                "http://schema.org/about": "UCSC genome browser bioinformatic utilities\n",
                "http://schema.org/url": "https://genome.ucsc.edu/util.html",
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "v358",
                    "http://schema.org/applicationCategory": "commandline tool",
                    "http://schema.org/downloadURL": "http://hgdownload.cse.ucsc.edu/admin/exe/userApps.v358.src.tgz"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-3.0"
                ]
            },
            "http://schema.org/name": "ucsc-bedgraphtobigwig",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/ucsc-bedgraphtobigwig.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "usage:\n   bedGraphToBigWig in.bedGraph chrom.sizes out.bw\nwhere in.bedGraph is a four column file in the format:\n      <chrom> <start> <end> <value>\nand chrom.sizes is a two-column file/URL: <chromosome name> <size in bases>\nand out.bw is the output indexed big wig file.\nIf the assembly <db> is hosted by UCSC, chrom.sizes can be a URL like\n  http://hgdownload.cse.ucsc.edu/goldenPath/<db>/bigZips/<db>.chrom.sizes\nor you may use the script fetchChromSizes to download the chrom.sizes file.\nIf not hosted by UCSC, a chrom.sizes file can be generated by running\ntwoBitInfo on the assembly .2bit file.\nThe input bedGraph file must be sorted, use the unix sort command:\n  sort -k1,1 -k2,2n unsorted.bedGraph > sorted.bedGraph\noptions:\n   -blockSize=N - Number of items to bundle in r-tree.  Default 256\n   -itemsPerSlot=N - Number of data points bundled at lowest level. Default 1024\n   -unc - If set, do not use compression.\n"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "sd:metadata": [
                "../metadata/chipseq-header.cwl"
            ],
            "sd:upstream": {
                "base_experiment": [
                    "trim-chipseq-pe.cwl",
                    "trim-atacseq-pe.cwl"
                ],
                "control_experiment": [
                    "trim-chipseq-pe.cwl",
                    "trim-atacseq-pe.cwl"
                ],
                "genome_indices": [
                    "genome-indices.cwl"
                ]
            },
            "inputs": [
                {
                    "type": "File",
                    "sd:upstreamSource": "base_experiment/bowtie_log",
                    "format": "http://edamontology.org/format_2330",
                    "label": "Read alignment log",
                    "doc": "Read alignment log file from Bowtie",
                    "id": "#main/alignment_log"
                },
                {
                    "type": "File",
                    "sd:upstreamSource": "genome_indices/annotation",
                    "label": "Genome annotation file",
                    "format": "http://edamontology.org/format_3475",
                    "doc": "Genome annotation file in TSV format",
                    "id": "#main/annotation_file"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "sd:upstreamSource": "base_experiment/bambai_pair",
                    "sd:localLabel": true,
                    "format": "http://edamontology.org/format_2572",
                    "label": "ChIP-Seq paired-end experiment",
                    "doc": "Coordinate sorted BAM alignment and index BAI files",
                    "id": "#main/bambai_pair"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "label": "Call broad peaks",
                    "doc": "Make MACS2 call broad peaks by linking nearby highly enriched regions",
                    "id": "#main/broad_peak"
                },
                {
                    "type": "File",
                    "sd:upstreamSource": "genome_indices/chrom_length",
                    "label": "Chromosome lengths file",
                    "format": "http://edamontology.org/format_2330",
                    "doc": "Chromosome lengths file in TSV format",
                    "id": "#main/chrom_length"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "default": null,
                    "sd:upstreamSource": "control_experiment/bambai_pair",
                    "sd:localLabel": true,
                    "label": "Control ChIP-Seq paired-end experiment",
                    "format": "http://edamontology.org/format_2572",
                    "doc": "Indexed BAM file from the ChIP-Seq paired-end experiment to be used as a control for MACS2 peak calling",
                    "id": "#main/control_file"
                },
                {
                    "type": "string",
                    "sd:upstreamSource": "genome_indices/genome_size",
                    "label": "Effective genome size",
                    "doc": "The length of the mappable genome (hs, mm, ce, dm or number, for example 2.7e9)",
                    "id": "#main/genome_size"
                },
                {
                    "type": "int",
                    "label": "Maximum fragment size",
                    "doc": "The maximum fragment size needed for read/pair inclusion",
                    "id": "#main/max_fragment_size"
                },
                {
                    "type": "int",
                    "label": "Minimum fragment size",
                    "doc": "The minimum fragment size needed for read/pair inclusion",
                    "id": "#main/min_fragment_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1000,
                    "sd:layout": {
                        "advanced": true
                    },
                    "label": "Max distance from gene TSS (in both direction) overlapping which the peak will be assigned to the promoter region",
                    "doc": "Max distance from gene TSS (in both direction) overlapping which the peak will be assigned to the promoter region",
                    "id": "#main/promoter_dist"
                },
                {
                    "type": "File",
                    "sd:upstreamSource": "base_experiment/samtools_rmdup_log",
                    "format": "http://edamontology.org/format_2330",
                    "label": "Remove duplicates log",
                    "doc": "Remove duplicates log file from Samtools",
                    "id": "#main/rmdup_log"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "label": "Number of threads",
                    "doc": "Number of threads for those steps that support multithreading",
                    "id": "#main/threads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20000,
                    "sd:layout": {
                        "advanced": true
                    },
                    "label": "Max distance from the promoter (only in upstream direction) overlapping which the peak will be assigned to the upstream region",
                    "doc": "Max distance from the promoter (only in upstream direction) overlapping which the peak will be assigned to the upstream region",
                    "id": "#main/upstream_dist"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "label": "Alignment filtering log",
                    "format": "http://edamontology.org/format_2330",
                    "doc": "Alignment filtering log from deepTool's alignmentSieve",
                    "outputSource": "#main/filter_bam/alignmentsieve_log",
                    "id": "#main/alignmentsieve_log"
                },
                {
                    "type": "File",
                    "label": "Average Tag Density Plot",
                    "format": "http://edamontology.org/format_3475",
                    "doc": "Average Tag Density Plot file in TSV format",
                    "outputSource": "#main/average_tag_density/result_file",
                    "sd:visualPlugins": [
                        {
                            "scatter": {
                                "tab": "QC Plots",
                                "Title": "Average Tag Density Plot",
                                "xAxisTitle": "Distance From TSS (bp)",
                                "yAxisTitle": "Average Tag Density (per bp)",
                                "colors": [
                                    "#b3de69"
                                ],
                                "height": 500,
                                "data": [
                                    "$1",
                                    "$2"
                                ],
                                "comparable": "atdp"
                            }
                        }
                    ],
                    "id": "#main/atdp_result"
                },
                {
                    "$import": "#main/bambai_pair"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3006",
                    "label": "Genome coverage",
                    "doc": "Genome coverage in bigWig format",
                    "outputSource": "#main/bam_to_bigwig/bigwig_file",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/bigwig/igvbrowser",
                                "type": "wig",
                                "name": "#main/bigwig/Genome Coverage",
                                "height": 120
                            }
                        }
                    ],
                    "id": "#main/bigwig"
                },
                {
                    "type": "File",
                    "label": "Gene annotated peaks",
                    "format": "http://edamontology.org/format_3475",
                    "doc": "MACS2 peak file annotated with nearby genes",
                    "outputSource": "#main/island_intersect/result_file",
                    "sd:visualPlugins": [
                        {
                            "syncfusiongrid": {
                                "tab": "Peak Calling",
                                "Title": "Peak Coordinates"
                            }
                        }
                    ],
                    "id": "#main/iaintersect_result"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "label": "Broad peaks",
                    "format": "http://edamontology.org/format_3614",
                    "doc": "Called peaks file in ENCODE broad peak format",
                    "outputSource": "#main/macs2_callpeak/broad_peak_file",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/macs2_broad_peaks/igvbrowser",
                                "type": "annotation",
                                "name": "#main/macs2_broad_peaks/Broad peaks",
                                "displayMode": "COLLAPSE",
                                "height": 40
                            }
                        }
                    ],
                    "id": "#main/macs2_broad_peaks"
                },
                {
                    "type": "File",
                    "label": "Called peaks",
                    "format": "http://edamontology.org/format_3468",
                    "doc": "Called peaks file with 1-based coordinates in XLS format",
                    "outputSource": "#main/macs2_callpeak/peak_xls_file",
                    "id": "#main/macs2_called_peaks"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "label": "Narrow peaks",
                    "format": "http://edamontology.org/format_3613",
                    "doc": "Called peaks file in ENCODE narrow peak format",
                    "outputSource": "#main/macs2_callpeak/narrow_peak_file",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/macs2_narrow_peaks/igvbrowser",
                                "type": "annotation",
                                "name": "#main/macs2_narrow_peaks/Narrow peaks",
                                "displayMode": "COLLAPSE",
                                "height": 40
                            }
                        }
                    ],
                    "id": "#main/macs2_narrow_peaks"
                }
            ],
            "steps": [
                {
                    "label": "Read enrichment around genes TSS",
                    "doc": "Generates average tag density plot around genes TSS as a lot of cis-regulatory\nelements are close to the TSS of their targets.\n",
                    "run": "#atdp.cwl",
                    "in": [
                        {
                            "source": "#main/annotation_file",
                            "id": "#main/average_tag_density/annotation_filename"
                        },
                        {
                            "default": 200,
                            "id": "#main/average_tag_density/avd_heat_window_bp"
                        },
                        {
                            "default": 50,
                            "id": "#main/average_tag_density/avd_smooth_bp"
                        },
                        {
                            "default": 5000,
                            "id": "#main/average_tag_density/avd_window_bp"
                        },
                        {
                            "default": "chrX chrY",
                            "id": "#main/average_tag_density/double_chr"
                        },
                        {
                            "default": "chrM",
                            "id": "#main/average_tag_density/ignore_chr"
                        },
                        {
                            "source": "#main/samtools_sort_index/bam_bai_pair",
                            "id": "#main/average_tag_density/input_file"
                        },
                        {
                            "source": "#main/get_statistics/mapped_reads",
                            "id": "#main/average_tag_density/mapped_reads"
                        }
                    ],
                    "out": [
                        "#main/average_tag_density/result_file",
                        "#main/average_tag_density/log_file"
                    ],
                    "id": "#main/average_tag_density"
                },
                {
                    "run": "#bam-bedgraph-bigwig.cwl",
                    "in": [
                        {
                            "source": "#main/samtools_sort_index/bam_bai_pair",
                            "id": "#main/bam_to_bigwig/bam_file"
                        },
                        {
                            "source": "#main/chrom_length",
                            "id": "#main/bam_to_bigwig/chrom_length_file"
                        },
                        {
                            "source": "#main/get_statistics/mapped_reads",
                            "id": "#main/bam_to_bigwig/mapped_reads_number"
                        },
                        {
                            "default": true,
                            "id": "#main/bam_to_bigwig/pairchip"
                        }
                    ],
                    "out": [
                        "#main/bam_to_bigwig/bigwig_file"
                    ],
                    "id": "#main/bam_to_bigwig"
                },
                {
                    "run": "#deeptools-alignmentsieve.cwl",
                    "in": [
                        {
                            "source": "#main/bambai_pair",
                            "id": "#main/filter_bam/bambai_pair"
                        },
                        {
                            "source": "#main/max_fragment_size",
                            "id": "#main/filter_bam/max_fragment_length"
                        },
                        {
                            "source": "#main/min_fragment_size",
                            "id": "#main/filter_bam/min_fragment_length"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/filter_bam/threads"
                        }
                    ],
                    "out": [
                        "#main/filter_bam/filtered_bam_file",
                        "#main/filter_bam/alignmentsieve_log"
                    ],
                    "id": "#main/filter_bam"
                },
                {
                    "run": "#python-get-stat-chipseq.cwl",
                    "in": [
                        {
                            "source": "#main/alignment_log",
                            "id": "#main/get_statistics/bowtie_log"
                        },
                        {
                            "source": "#main/rmdup_log",
                            "id": "#main/get_statistics/rmdup_log"
                        }
                    ],
                    "out": [
                        "#main/get_statistics/mapped_reads"
                    ],
                    "id": "#main/get_statistics"
                },
                {
                    "label": "Peak annotation",
                    "doc": "Assigns nearest genes to peaks to explore the biological implication of the open\nchromatin binding sites.\n",
                    "run": "#iaintersect.cwl",
                    "in": [
                        {
                            "source": "#main/annotation_file",
                            "id": "#main/island_intersect/annotation_filename"
                        },
                        {
                            "source": "#main/macs2_callpeak/peak_xls_file",
                            "id": "#main/island_intersect/input_filename"
                        },
                        {
                            "source": "#main/promoter_dist",
                            "id": "#main/island_intersect/promoter_bp"
                        },
                        {
                            "source": "#main/upstream_dist",
                            "id": "#main/island_intersect/upstream_bp"
                        }
                    ],
                    "out": [
                        "#main/island_intersect/result_file",
                        "#main/island_intersect/log_file"
                    ],
                    "id": "#main/island_intersect"
                },
                {
                    "label": "Peak detection",
                    "doc": "Identifies enriched with aligned reads genome areas. Those areas correspond to the\ntranscription factor binding sites.\n",
                    "run": "#macs2-callpeak.cwl",
                    "in": [
                        {
                            "source": "#main/broad_peak",
                            "id": "#main/macs2_callpeak/broad"
                        },
                        {
                            "default": 10000,
                            "id": "#main/macs2_callpeak/buffer_size"
                        },
                        {
                            "source": "#main/broad_peak",
                            "valueFrom": "$(!self)",
                            "id": "#main/macs2_callpeak/call_summits"
                        },
                        {
                            "source": "#main/control_file",
                            "id": "#main/macs2_callpeak/control_file"
                        },
                        {
                            "default": "BAMPE",
                            "id": "#main/macs2_callpeak/format_mode"
                        },
                        {
                            "source": "#main/genome_size",
                            "id": "#main/macs2_callpeak/genome_size"
                        },
                        {
                            "default": "auto",
                            "id": "#main/macs2_callpeak/keep_dup"
                        },
                        {
                            "default": "4 40",
                            "id": "#main/macs2_callpeak/mfold"
                        },
                        {
                            "source": "#main/control_file",
                            "valueFrom": "$(!self)",
                            "id": "#main/macs2_callpeak/nolambda"
                        },
                        {
                            "default": 0.05,
                            "id": "#main/macs2_callpeak/q_value"
                        },
                        {
                            "source": "#main/samtools_sort_index/bam_bai_pair",
                            "id": "#main/macs2_callpeak/treatment_file"
                        },
                        {
                            "default": 3,
                            "id": "#main/macs2_callpeak/verbose"
                        }
                    ],
                    "out": [
                        "#main/macs2_callpeak/peak_xls_file",
                        "#main/macs2_callpeak/narrow_peak_file",
                        "#main/macs2_callpeak/broad_peak_file"
                    ],
                    "id": "#main/macs2_callpeak"
                },
                {
                    "run": "#samtools-sort-index.cwl",
                    "in": [
                        {
                            "source": "#main/filter_bam/filtered_bam_file",
                            "id": "#main/samtools_sort_index/sort_input"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/samtools_sort_index/threads"
                        }
                    ],
                    "out": [
                        "#main/samtools_sort_index/bam_bai_pair"
                    ],
                    "id": "#main/samtools_sort_index"
                }
            ],
            "label": "Cut-n-Run pipeline paired-end",
            "doc": "Experimental pipeline for Cut-n-Run analysis. Uses mapping results from the following experiment types:\n\n- `chipseq-pe.cwl`\n- `trim-chipseq-pe.cwl`\n- `trim-atacseq-pe.cwl`\n\nNote, the upstream analyses should not have duplicates removed",
            "id": "#main",
            "http://schema.org/name": "Cut-n-Run pipeline paired-end",
            "http://schema.org/alternateName": "Cut-n-Run analysis workflow for paired-end data",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/datirium/workflows/master/workflows/datirium/trim-chipseq-pe.cwl",
            "http://schema.org/codeRepository": "https://github.com/datirium/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://github.com/schemaorg/schemaorg/raw/main/data/releases/11.01/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
